# xms-client
XMS is the controller of distributed storage system

This Python package is automatically generated by the [Swagger Codegen](https://github.com/swagger-api/swagger-codegen) project:

- API version: 3.2.14
- Package version: 3.2.14
- Build package: io.swagger.codegen.languages.PythonClientCodegen

## Requirements.

Python 2.7 and 3.4+

## Installation & Usage
### pip install

If the python package is hosted on Github, you can install directly from Github

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import xms_client 
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import xms_client
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python
from __future__ import print_function
import time
import xms_client
from xms_client.rest import ApiException
from pprint import pprint

# Configure API key authorization: tokenInCookie
xms_client.configuration.api_key['XMS_AUTH_TOKEN'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# xms_client.configuration.api_key_prefix['XMS_AUTH_TOKEN'] = 'Bearer'
# Configure API key authorization: tokenInHeader
xms_client.configuration.api_key['Xms-Auth-Token'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# xms_client.configuration.api_key_prefix['Xms-Auth-Token'] = 'Bearer'
# Configure API key authorization: tokenInQuery
xms_client.configuration.api_key['token'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# xms_client.configuration.api_key_prefix['token'] = 'Bearer'
# create an instance of the API class
api_instance = xms_client.AccessPathsApi()
access_path = xms_client.AccessPathCreateReq() # AccessPathCreateReq | access path info

try:
    api_response = api_instance.create_access_path(access_path)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling AccessPathsApi->create_access_path: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *https://localhost/v1*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*AccessPathsApi* | [**create_access_path**](docs/AccessPathsApi.md#create_access_path) | **POST** /access-paths/ | 
*AccessPathsApi* | [**delete_access_path**](docs/AccessPathsApi.md#delete_access_path) | **DELETE** /access-paths/{access_path_id} | 
*AccessPathsApi* | [**get_access_path**](docs/AccessPathsApi.md#get_access_path) | **GET** /access-paths/{access_path_id} | 
*AccessPathsApi* | [**list_access_paths**](docs/AccessPathsApi.md#list_access_paths) | **GET** /access-paths/ | 
*AccessPathsApi* | [**update_access_path**](docs/AccessPathsApi.md#update_access_path) | **PATCH** /access-paths/{access_path_id} | 
*AccessTokensApi* | [**create_access_token**](docs/AccessTokensApi.md#create_access_token) | **POST** /access-tokens/ | 
*AccessTokensApi* | [**delete_access_token**](docs/AccessTokensApi.md#delete_access_token) | **DELETE** /access-tokens/{access_token_id} | 
*AccessTokensApi* | [**get_access_token**](docs/AccessTokensApi.md#get_access_token) | **GET** /access-tokens/{access_token_id} | 
*AccessTokensApi* | [**list_access_tokens**](docs/AccessTokensApi.md#list_access_tokens) | **GET** /access-tokens/ | 
*AccessTokensApi* | [**regenerate_access_token**](docs/AccessTokensApi.md#regenerate_access_token) | **POST** /access-tokens/{access_token_id}:regenerate | 
*AccessTokensApi* | [**update_access_token**](docs/AccessTokensApi.md#update_access_token) | **PATCH** /access-tokens/{access_token_id} | 
*AccessTokensApi* | [**validate_access_token**](docs/AccessTokensApi.md#validate_access_token) | **POST** /access-tokens:validate | 
*ActionLogsApi* | [**list_action_logs**](docs/ActionLogsApi.md#list_action_logs) | **GET** /action-logs/ | 
*AlertGroupsApi* | [**create_alert_group**](docs/AlertGroupsApi.md#create_alert_group) | **POST** /alert-groups/ | 
*AlertGroupsApi* | [**delete_alert_group**](docs/AlertGroupsApi.md#delete_alert_group) | **DELETE** /alert-groups/{group_id} | 
*AlertGroupsApi* | [**get_alert_group**](docs/AlertGroupsApi.md#get_alert_group) | **GET** /alert-groups/{group_id} | 
*AlertGroupsApi* | [**list_alert_groups**](docs/AlertGroupsApi.md#list_alert_groups) | **GET** /alert-groups/ | 
*AlertGroupsApi* | [**update_alert_group**](docs/AlertGroupsApi.md#update_alert_group) | **PATCH** /alert-groups/{group_id} | 
*AlertRulesApi* | [**create_alert_rule**](docs/AlertRulesApi.md#create_alert_rule) | **PUT** /alert-rules/ | 
*AlertRulesApi* | [**create_alert_rule_0**](docs/AlertRulesApi.md#create_alert_rule_0) | **POST** /alert-rules/ | 
*AlertRulesApi* | [**delete_alert_rule**](docs/AlertRulesApi.md#delete_alert_rule) | **DELETE** /alert-rules/{rule_id} | 
*AlertRulesApi* | [**get_alert_rule**](docs/AlertRulesApi.md#get_alert_rule) | **GET** /alert-rules/{rule_id} | 
*AlertRulesApi* | [**get_alert_rule_schema**](docs/AlertRulesApi.md#get_alert_rule_schema) | **GET** /alert-rules/schema | 
*AlertRulesApi* | [**list_alert_rules**](docs/AlertRulesApi.md#list_alert_rules) | **GET** /alert-rules/ | 
*AlertRulesApi* | [**update_alert_rule**](docs/AlertRulesApi.md#update_alert_rule) | **PATCH** /alert-rules/{rule_id} | 
*AlertsApi* | [**count_alerts**](docs/AlertsApi.md#count_alerts) | **GET** /alerts/stats | 
*AlertsApi* | [**delete_alerts**](docs/AlertsApi.md#delete_alerts) | **DELETE** /alerts/ | 
*AlertsApi* | [**do_alert**](docs/AlertsApi.md#do_alert) | **PUT** /alerts/{alert_id} | 
*AlertsApi* | [**do_alerts**](docs/AlertsApi.md#do_alerts) | **PATCH** /alerts/ | 
*AlertsApi* | [**list_alerts**](docs/AlertsApi.md#list_alerts) | **GET** /alerts/ | 
*AuthApi* | [**create_token**](docs/AuthApi.md#create_token) | **POST** /auth/tokens | 
*AuthApi* | [**login**](docs/AuthApi.md#login) | **POST** /auth/tokens:login | 
*AuthApi* | [**logout**](docs/AuthApi.md#logout) | **POST** /auth/tokens:logout | 
*BlockSnapshotsApi* | [**create_block_snapshot**](docs/BlockSnapshotsApi.md#create_block_snapshot) | **POST** /block-snapshots/ | 
*BlockSnapshotsApi* | [**delete_block_snapshot**](docs/BlockSnapshotsApi.md#delete_block_snapshot) | **DELETE** /block-snapshots/{snapshot_id} | 
*BlockSnapshotsApi* | [**get_block_snapshot**](docs/BlockSnapshotsApi.md#get_block_snapshot) | **GET** /block-snapshots/{block_snapshot_id} | 
*BlockSnapshotsApi* | [**list_block_snapshots**](docs/BlockSnapshotsApi.md#list_block_snapshots) | **GET** /block-snapshots/ | 
*BlockSnapshotsApi* | [**update_snapshot**](docs/BlockSnapshotsApi.md#update_snapshot) | **PATCH** /block-snapshots/{snapshot_id} | 
*BlockVolumeGroupSnapshotsApi* | [**create_block_volume_group_snapshot**](docs/BlockVolumeGroupSnapshotsApi.md#create_block_volume_group_snapshot) | **POST** /block-volume-group-snapshots/ | 
*BlockVolumeGroupSnapshotsApi* | [**delete_block_volume_group_snapshot**](docs/BlockVolumeGroupSnapshotsApi.md#delete_block_volume_group_snapshot) | **DELETE** /block-volume-group-snapshots/{block_volume_group_snapshot_id} | 
*BlockVolumeGroupSnapshotsApi* | [**get_block_volume_group_snapshot**](docs/BlockVolumeGroupSnapshotsApi.md#get_block_volume_group_snapshot) | **GET** /block-volume-group-snapshots/{block_volume_group_snapshot_id} | 
*BlockVolumeGroupSnapshotsApi* | [**list_block_volume_group_snapshots**](docs/BlockVolumeGroupSnapshotsApi.md#list_block_volume_group_snapshots) | **GET** /block-volume-group-snapshots/ | 
*BlockVolumeGroupSnapshotsApi* | [**update_block_volume_group_snapshot**](docs/BlockVolumeGroupSnapshotsApi.md#update_block_volume_group_snapshot) | **PATCH** /block-volume-group-snapshots/{block_volume_group_snapshot_id} | 
*BlockVolumeGroupsApi* | [**add_block_volume_to_block_volume_group**](docs/BlockVolumeGroupsApi.md#add_block_volume_to_block_volume_group) | **PUT** /block-volume-groups/{block_volume_group_id}/block-volumes | 
*BlockVolumeGroupsApi* | [**create_block_volume_group**](docs/BlockVolumeGroupsApi.md#create_block_volume_group) | **POST** /block-volume-groups/ | 
*BlockVolumeGroupsApi* | [**delete_block_volume_group**](docs/BlockVolumeGroupsApi.md#delete_block_volume_group) | **DELETE** /block-volume-groups/{block_volume_group_id} | 
*BlockVolumeGroupsApi* | [**get_block_volume_group**](docs/BlockVolumeGroupsApi.md#get_block_volume_group) | **GET** /block-volume-groups/{block_volume_group_id} | 
*BlockVolumeGroupsApi* | [**list_block_volume_groups**](docs/BlockVolumeGroupsApi.md#list_block_volume_groups) | **GET** /block-volume-groups/ | 
*BlockVolumeGroupsApi* | [**remove_block_volume_from_block_volume_group**](docs/BlockVolumeGroupsApi.md#remove_block_volume_from_block_volume_group) | **DELETE** /block-volume-groups/{block_volume_group_id}/block-volumes | 
*BlockVolumeGroupsApi* | [**update_block_volume_group**](docs/BlockVolumeGroupsApi.md#update_block_volume_group) | **PATCH** /block-volume-groups/{block_volume_group_id} | 
*BlockVolumesApi* | [**batch_get_block_volume_samples**](docs/BlockVolumesApi.md#batch_get_block_volume_samples) | **GET** /block-volumes/samples | 
*BlockVolumesApi* | [**create_block_volume**](docs/BlockVolumesApi.md#create_block_volume) | **POST** /block-volumes/ | 
*BlockVolumesApi* | [**delete_block_volume**](docs/BlockVolumesApi.md#delete_block_volume) | **DELETE** /block-volumes/{block_volume_id} | 
*BlockVolumesApi* | [**get_block_volume**](docs/BlockVolumesApi.md#get_block_volume) | **GET** /block-volumes/{block_volume_id} | 
*BlockVolumesApi* | [**get_block_volume_samples**](docs/BlockVolumesApi.md#get_block_volume_samples) | **GET** /block-volumes/{block_volume_id}/samples | 
*BlockVolumesApi* | [**list_block_volumes**](docs/BlockVolumesApi.md#list_block_volumes) | **GET** /block-volumes/ | 
*BlockVolumesApi* | [**migrate_block_volume**](docs/BlockVolumesApi.md#migrate_block_volume) | **POST** /block-volumes/{block_volume_id}:migrate | 
*BlockVolumesApi* | [**rebuild_block_volume_replication**](docs/BlockVolumesApi.md#rebuild_block_volume_replication) | **POST** /block-volumes/{block_volume_id}:rebuild-replication | 
*BlockVolumesApi* | [**set_block_volume_replication**](docs/BlockVolumesApi.md#set_block_volume_replication) | **POST** /block-volumes/{block_volume_id}:set-replication | 
*BlockVolumesApi* | [**set_block_volume_replication_0**](docs/BlockVolumesApi.md#set_block_volume_replication_0) | **POST** /block-volumes/{block_volume_id}:unset-replication | 
*BlockVolumesApi* | [**set_snapshot_protection**](docs/BlockVolumesApi.md#set_snapshot_protection) | **POST** /block-volumes/{block_volume_id}:set-snapshot-protection | 
*BlockVolumesApi* | [**suspend_block_volume_replication**](docs/BlockVolumesApi.md#suspend_block_volume_replication) | **POST** /block-volumes/{block_volume_id}:suspend-replication | 
*BlockVolumesApi* | [**unset_snapshot_protection**](docs/BlockVolumesApi.md#unset_snapshot_protection) | **POST** /block-volumes/{block_volume_id}:unset-snapshot-protection | 
*BlockVolumesApi* | [**update_block_volume**](docs/BlockVolumesApi.md#update_block_volume) | **PATCH** /block-volumes/{block_volume_id} | 
*BlockVolumesApi* | [**update_migration**](docs/BlockVolumesApi.md#update_migration) | **POST** /block-volumes/{block_volume_id}:update-migration | 
*ChunksApi* | [**get_chunk**](docs/ChunksApi.md#get_chunk) | **GET** /chunks/{chunk_id} | 
*ClientCodesApi* | [**clear_client_codes**](docs/ClientCodesApi.md#clear_client_codes) | **DELETE** /client-codes/ | 
*ClientCodesApi* | [**delete_client_code**](docs/ClientCodesApi.md#delete_client_code) | **DELETE** /client-codes/{client_code_id} | 
*ClientCodesApi* | [**list_client_codes**](docs/ClientCodesApi.md#list_client_codes) | **GET** /client-codes/ | 
*ClientGroupsApi* | [**create_client_group**](docs/ClientGroupsApi.md#create_client_group) | **POST** /client-groups/ | 
*ClientGroupsApi* | [**delete_client_group**](docs/ClientGroupsApi.md#delete_client_group) | **DELETE** /client-groups/{client_group_id} | 
*ClientGroupsApi* | [**get_client_group**](docs/ClientGroupsApi.md#get_client_group) | **GET** /client-groups/{client_group_id} | 
*ClientGroupsApi* | [**list_client_groups**](docs/ClientGroupsApi.md#list_client_groups) | **GET** /client-groups/ | 
*ClientGroupsApi* | [**update_client_group**](docs/ClientGroupsApi.md#update_client_group) | **PATCH** /client-groups/{client_group_id} | 
*ClientLunMappingsApi* | [**get_client_lun_mapping**](docs/ClientLunMappingsApi.md#get_client_lun_mapping) | **GET** /client-lun-mappings/{client_lun_mapping_id} | 
*ClientLunMappingsApi* | [**list_client_lun_mappings**](docs/ClientLunMappingsApi.md#list_client_lun_mappings) | **GET** /client-lun-mappings/ | 
*CloudInstancesApi* | [**get_cloud_instance**](docs/CloudInstancesApi.md#get_cloud_instance) | **GET** /cloud-instances/{cloud_instance_id} | 
*CloudInstancesApi* | [**get_cloud_instance_samples**](docs/CloudInstancesApi.md#get_cloud_instance_samples) | **GET** /cloud-instances/{cloud_instance_id}/samples | 
*CloudInstancesApi* | [**list_cloud_instances**](docs/CloudInstancesApi.md#list_cloud_instances) | **GET** /cloud-instances/ | 
*CloudPlatformsApi* | [**create_cloud_platform**](docs/CloudPlatformsApi.md#create_cloud_platform) | **POST** /cloud-platforms/ | 
*CloudPlatformsApi* | [**delete_cloud_platform**](docs/CloudPlatformsApi.md#delete_cloud_platform) | **DELETE** /cloud-platforms/{cloud_platform_id} | 
*CloudPlatformsApi* | [**get_cloud_platform**](docs/CloudPlatformsApi.md#get_cloud_platform) | **GET** /cloud-platforms/{cloud_platform_id} | 
*CloudPlatformsApi* | [**list_cloud_platforms**](docs/CloudPlatformsApi.md#list_cloud_platforms) | **GET** /cloud-platforms/ | 
*CloudPlatformsApi* | [**sync_cloud_platform**](docs/CloudPlatformsApi.md#sync_cloud_platform) | **POST** /cloud-platforms/{cloud_platform_id}:sync | 
*CloudPlatformsApi* | [**update_cloud_platform**](docs/CloudPlatformsApi.md#update_cloud_platform) | **PATCH** /cloud-platforms/{cloud_platform_id} | 
*CloudVolumeAttachmentsApi* | [**list_cloud_volume_attachments**](docs/CloudVolumeAttachmentsApi.md#list_cloud_volume_attachments) | **GET** /cloud-volume-attachments/ | 
*CloudVolumesApi* | [**get_cloud_volume**](docs/CloudVolumesApi.md#get_cloud_volume) | **GET** /cloud-volumes/{cloud_volume_id} | 
*CloudVolumesApi* | [**list_cloud_volumes**](docs/CloudVolumesApi.md#list_cloud_volumes) | **GET** /cloud-volumes/ | 
*ClusterApi* | [**boot_node**](docs/ClusterApi.md#boot_node) | **GET** /cluster/bootnode | 
*ClusterApi* | [**cluster**](docs/ClusterApi.md#cluster) | **GET** /cluster/ | 
*ClusterApi* | [**delete_object_storage**](docs/ClusterApi.md#delete_object_storage) | **DELETE** /cluster/object-storage | 
*ClusterApi* | [**get_action_log_report**](docs/ClusterApi.md#get_action_log_report) | **GET** /cluster/action-log-report | 
*ClusterApi* | [**get_alert_report**](docs/ClusterApi.md#get_alert_report) | **GET** /cluster/alert-report | 
*ClusterApi* | [**get_cluster_overview**](docs/ClusterApi.md#get_cluster_overview) | **GET** /cluster/stats | 
*ClusterApi* | [**get_cluster_report**](docs/ClusterApi.md#get_cluster_report) | **GET** /cluster/report | 
*ClusterApi* | [**get_cluster_samples**](docs/ClusterApi.md#get_cluster_samples) | **GET** /cluster/samples | 
*ClusterApi* | [**get_event_log_report**](docs/ClusterApi.md#get_event_log_report) | **GET** /cluster/event-log-report | 
*ClusterApi* | [**get_object_storage**](docs/ClusterApi.md#get_object_storage) | **GET** /cluster/object-storage | 
*ClusterApi* | [**get_stats_usage_prediction**](docs/ClusterApi.md#get_stats_usage_prediction) | **GET** /cluster/stats-usage-prediction | 
*ClusterApi* | [**init_object_storage**](docs/ClusterApi.md#init_object_storage) | **PUT** /cluster/object-storage | 
*ClusterApi* | [**installation**](docs/ClusterApi.md#installation) | **GET** /cluster/installation | 
*ClusterApi* | [**remove_cluster_access_info**](docs/ClusterApi.md#remove_cluster_access_info) | **POST** /cluster:remove-access-info | 
*ClusterApi* | [**server_time**](docs/ClusterApi.md#server_time) | **GET** /cluster/time | 
*ClusterApi* | [**set_boot_node**](docs/ClusterApi.md#set_boot_node) | **PUT** /cluster/bootnode | 
*ClusterApi* | [**set_cluster_access_info**](docs/ClusterApi.md#set_cluster_access_info) | **POST** /cluster:set-access-info | 
*ClusterApi* | [**set_object_storage**](docs/ClusterApi.md#set_object_storage) | **PATCH** /cluster/object-storage | 
*ClusterApi* | [**update_cluster**](docs/ClusterApi.md#update_cluster) | **PATCH** /cluster/ | 
*ClusterApi* | [**update_cluster_maintenance**](docs/ClusterApi.md#update_cluster_maintenance) | **PUT** /cluster/maintenance | 
*ConfsApi* | [**delete_conf_item**](docs/ConfsApi.md#delete_conf_item) | **DELETE** /confs/{type}/{key} | 
*ConfsApi* | [**get_conf_item**](docs/ConfsApi.md#get_conf_item) | **GET** /confs/{type}/{key} | 
*ConfsApi* | [**list_conf_items**](docs/ConfsApi.md#list_conf_items) | **GET** /confs/{type} | 
*ConfsApi* | [**set_conf_item**](docs/ConfsApi.md#set_conf_item) | **PUT** /confs/ | 
*ConfsApi* | [**set_conf_items**](docs/ConfsApi.md#set_conf_items) | **PUT** /confs/{type} | 
*CryptoKeysApi* | [**create_crypto_key**](docs/CryptoKeysApi.md#create_crypto_key) | **POST** /crypto-keys/ | 
*CryptoKeysApi* | [**download_crypto_key**](docs/CryptoKeysApi.md#download_crypto_key) | **GET** /crypto-keys/{key_id}/key | 
*CryptoKeysApi* | [**get_crypto_key**](docs/CryptoKeysApi.md#get_crypto_key) | **GET** /crypto-keys/{key_id} | 
*CryptoKeysApi* | [**list_crypto_keys**](docs/CryptoKeysApi.md#list_crypto_keys) | **GET** /crypto-keys/ | 
*CryptoKeysApi* | [**update_crypto_key**](docs/CryptoKeysApi.md#update_crypto_key) | **PATCH** /crypto-keys/{key_id} | 
*DisksApi* | [**create_partitions**](docs/DisksApi.md#create_partitions) | **PUT** /disks/{disk_id}/partitions | 
*DisksApi* | [**delete_partitions**](docs/DisksApi.md#delete_partitions) | **DELETE** /disks/{disk_id}/partitions | 
*DisksApi* | [**get_disk**](docs/DisksApi.md#get_disk) | **GET** /disks/{disk_id} | 
*DisksApi* | [**get_disk_samples**](docs/DisksApi.md#get_disk_samples) | **GET** /disks/{disk_id}/samples | 
*DisksApi* | [**list_disks**](docs/DisksApi.md#list_disks) | **GET** /disks/ | 
*DisksApi* | [**update_disk**](docs/DisksApi.md#update_disk) | **PATCH** /disks/{disk_id} | 
*DpBlockReplicationPoliciesApi* | [**create_dp_block_replication_policy**](docs/DpBlockReplicationPoliciesApi.md#create_dp_block_replication_policy) | **POST** /dp-block-replication-policies/ | 
*DpBlockReplicationPoliciesApi* | [**delete_dp_block_replication_policy**](docs/DpBlockReplicationPoliciesApi.md#delete_dp_block_replication_policy) | **DELETE** /dp-block-replication-policies/{policy_id} | 
*DpBlockReplicationPoliciesApi* | [**get_dp_block_replication_policy**](docs/DpBlockReplicationPoliciesApi.md#get_dp_block_replication_policy) | **GET** /dp-block-replication-policies/{policy_id} | 
*DpBlockReplicationPoliciesApi* | [**list_dp_block_replication_policies**](docs/DpBlockReplicationPoliciesApi.md#list_dp_block_replication_policies) | **GET** /dp-block-replication-policies/ | 
*DpBlockReplicationPoliciesApi* | [**update_dp_block_replication_policy**](docs/DpBlockReplicationPoliciesApi.md#update_dp_block_replication_policy) | **PATCH** /dp-block-replication-policies/{policy_id} | 
*DpBlockSnapshotJobsApi* | [**list_dp_block_snapshot_jobs**](docs/DpBlockSnapshotJobsApi.md#list_dp_block_snapshot_jobs) | **GET** /dp-block-snapshot-jobs/ | 
*DpBlockSnapshotPlansApi* | [**create_dp_block_snapshot_plan**](docs/DpBlockSnapshotPlansApi.md#create_dp_block_snapshot_plan) | **POST** /dp-block-snapshot-plans/ | 
*DpBlockSnapshotPlansApi* | [**delete_dp_block_snapshot_plan**](docs/DpBlockSnapshotPlansApi.md#delete_dp_block_snapshot_plan) | **DELETE** /dp-block-snapshot-plans/{plan_id} | 
*DpBlockSnapshotPlansApi* | [**get_dp_block_snapshot_plan**](docs/DpBlockSnapshotPlansApi.md#get_dp_block_snapshot_plan) | **GET** /dp-block-snapshot-plans/{plan_id} | 
*DpBlockSnapshotPlansApi* | [**list_dp_block_snapshot_plans**](docs/DpBlockSnapshotPlansApi.md#list_dp_block_snapshot_plans) | **GET** /dp-block-snapshot-plans/ | 
*DpBlockSnapshotPlansApi* | [**update_dp_block_snapshot_plan**](docs/DpBlockSnapshotPlansApi.md#update_dp_block_snapshot_plan) | **PATCH** /dp-block-snapshot-plans/{plan_id} | 
*DpBlockSnapshotPoliciesApi* | [**create_dp_block_snapshot_policy**](docs/DpBlockSnapshotPoliciesApi.md#create_dp_block_snapshot_policy) | **POST** /dp-block-snapshot-policies/ | 
*DpBlockSnapshotPoliciesApi* | [**delete_dp_block_snapshot_policy**](docs/DpBlockSnapshotPoliciesApi.md#delete_dp_block_snapshot_policy) | **DELETE** /dp-block-snapshot-policies/{policy_id} | 
*DpBlockSnapshotPoliciesApi* | [**get_dp_block_snapshot_policy**](docs/DpBlockSnapshotPoliciesApi.md#get_dp_block_snapshot_policy) | **GET** /dp-block-snapshot-policies/{policy_id} | 
*DpBlockSnapshotPoliciesApi* | [**list_dp_block_snapshot_policies**](docs/DpBlockSnapshotPoliciesApi.md#list_dp_block_snapshot_policies) | **GET** /dp-block-snapshot-policies/ | 
*DpBlockSnapshotPoliciesApi* | [**update_dp_block_snapshot_policy**](docs/DpBlockSnapshotPoliciesApi.md#update_dp_block_snapshot_policy) | **PATCH** /dp-block-snapshot-policies/{policy_id} | 
*DpBlockSnapshotRecoveryJobsApi* | [**create_dp_block_snapshot_recovery_job**](docs/DpBlockSnapshotRecoveryJobsApi.md#create_dp_block_snapshot_recovery_job) | **POST** /dp-block-snapshot-recovery-jobs/ | 
*DpBlockSnapshotRecoveryJobsApi* | [**delete_dp_block_snapshot_recovery_job**](docs/DpBlockSnapshotRecoveryJobsApi.md#delete_dp_block_snapshot_recovery_job) | **DELETE** /dp-block-snapshot-recovery-jobs/{job_id} | 
*DpBlockSnapshotRecoveryJobsApi* | [**get_dp_block_snapshot_recovery_job**](docs/DpBlockSnapshotRecoveryJobsApi.md#get_dp_block_snapshot_recovery_job) | **GET** /dp-block-snapshot-recovery-jobs/{job_id} | 
*DpBlockSnapshotRecoveryJobsApi* | [**list_dp_block_snapshot_recovery_jobs**](docs/DpBlockSnapshotRecoveryJobsApi.md#list_dp_block_snapshot_recovery_jobs) | **GET** /dp-block-snapshot-recovery-jobs/ | 
*DpGatewaysApi* | [**create_dp_gateway**](docs/DpGatewaysApi.md#create_dp_gateway) | **POST** /dp-gateways/ | 
*DpGatewaysApi* | [**delete_dp_gateway**](docs/DpGatewaysApi.md#delete_dp_gateway) | **DELETE** /dp-gateways/{gateway_id} | 
*DpGatewaysApi* | [**get_dp_gateway**](docs/DpGatewaysApi.md#get_dp_gateway) | **GET** /dp-gateways/{gateway_id} | 
*DpGatewaysApi* | [**list_dp_gateways**](docs/DpGatewaysApi.md#list_dp_gateways) | **GET** /dp-gateways/ | 
*DpGatewaysApi* | [**update_dp_gateway**](docs/DpGatewaysApi.md#update_dp_gateway) | **PATCH** /dp-gateways/{gateway_id} | 
*DpSitesApi* | [**create_dp_site**](docs/DpSitesApi.md#create_dp_site) | **POST** /dp-sites/ | 
*DpSitesApi* | [**delete_dp_site**](docs/DpSitesApi.md#delete_dp_site) | **DELETE** /dp-sites/{site_id} | 
*DpSitesApi* | [**get_backup_block_snapshots**](docs/DpSitesApi.md#get_backup_block_snapshots) | **GET** /dp-sites/{site_id}/backup-block-snapshots | 
*DpSitesApi* | [**get_backup_block_volumes**](docs/DpSitesApi.md#get_backup_block_volumes) | **GET** /dp-sites/{site_id}/backup-block-volumes | 
*DpSitesApi* | [**get_backup_clusters**](docs/DpSitesApi.md#get_backup_clusters) | **GET** /dp-sites/{site_id}/backup-clusters | 
*DpSitesApi* | [**get_dp_site**](docs/DpSitesApi.md#get_dp_site) | **GET** /dp-sites/{site_id} | 
*DpSitesApi* | [**list_dp_sites**](docs/DpSitesApi.md#list_dp_sites) | **GET** /dp-sites/ | 
*DpSitesApi* | [**update_dp_site**](docs/DpSitesApi.md#update_dp_site) | **PATCH** /dp-sites/{site_id} | 
*EmailGroupsApi* | [**create_email_group**](docs/EmailGroupsApi.md#create_email_group) | **POST** /email-groups/ | 
*EmailGroupsApi* | [**delete_email_group**](docs/EmailGroupsApi.md#delete_email_group) | **DELETE** /email-groups/{group_id} | 
*EmailGroupsApi* | [**get_email_group**](docs/EmailGroupsApi.md#get_email_group) | **GET** /email-groups/{group_id} | 
*EmailGroupsApi* | [**list_email_groups**](docs/EmailGroupsApi.md#list_email_groups) | **GET** /email-groups/ | 
*EmailGroupsApi* | [**update_email_group**](docs/EmailGroupsApi.md#update_email_group) | **PUT** /email-groups/{group_id} | 
*EmailsApi* | [**get_email_config**](docs/EmailsApi.md#get_email_config) | **GET** /emails/config | 
*EmailsApi* | [**send_email**](docs/EmailsApi.md#send_email) | **POST** /emails/ | 
*EmailsApi* | [**update_email_config**](docs/EmailsApi.md#update_email_config) | **PATCH** /emails/config | 
*EventLogsApi* | [**list_event_logs**](docs/EventLogsApi.md#list_event_logs) | **GET** /event-logs/ | 
*FsAccessGroupsApi* | [**add_fs_members**](docs/FsAccessGroupsApi.md#add_fs_members) | **PUT** /fs-access-groups/{fs_access_group_id}/fs-members | 
*FsAccessGroupsApi* | [**create_fs_access_group**](docs/FsAccessGroupsApi.md#create_fs_access_group) | **POST** /fs-access-groups/ | 
*FsAccessGroupsApi* | [**delete_fs_access_group**](docs/FsAccessGroupsApi.md#delete_fs_access_group) | **DELETE** /fs-access-groups/{fs_access_group_id} | 
*FsAccessGroupsApi* | [**get_fs_access_group**](docs/FsAccessGroupsApi.md#get_fs_access_group) | **GET** /fs-access-groups/{fs_access_group_id} | 
*FsAccessGroupsApi* | [**list_fs_access_groups**](docs/FsAccessGroupsApi.md#list_fs_access_groups) | **GET** /fs-access-groups/ | 
*FsAccessGroupsApi* | [**remove_fs_members**](docs/FsAccessGroupsApi.md#remove_fs_members) | **DELETE** /fs-access-groups/{fs_access_group_id}/fs-members | 
*FsAccessGroupsApi* | [**update_fs_access_group**](docs/FsAccessGroupsApi.md#update_fs_access_group) | **PATCH** /fs-access-groups/{fs_access_group_id} | 
*FsActiveDirectoriesApi* | [**create_fs_active_directory**](docs/FsActiveDirectoriesApi.md#create_fs_active_directory) | **POST** /fs-active-directories/ | 
*FsActiveDirectoriesApi* | [**delete_fs_active_directory**](docs/FsActiveDirectoriesApi.md#delete_fs_active_directory) | **DELETE** /fs-active-directories/{fs_active_directory_id} | 
*FsActiveDirectoriesApi* | [**get_fs_active_directory**](docs/FsActiveDirectoriesApi.md#get_fs_active_directory) | **GET** /fs-active-directories/{fs_active_directory_id} | 
*FsActiveDirectoriesApi* | [**list_fs_active_directories**](docs/FsActiveDirectoriesApi.md#list_fs_active_directories) | **GET** /fs-active-directories/ | 
*FsActiveDirectoriesApi* | [**sync_fs_active_directory**](docs/FsActiveDirectoriesApi.md#sync_fs_active_directory) | **POST** /fs-active-directories/{fs_active_directory_id}:sync | 
*FsActiveDirectoriesApi* | [**update_fs_active_directory**](docs/FsActiveDirectoriesApi.md#update_fs_active_directory) | **PATCH** /fs-active-directories/{fs_active_directory_id} | 
*FsAdUsersApi* | [**get_fsad_user**](docs/FsAdUsersApi.md#get_fsad_user) | **GET** /fs-ad-users/{fs_ad_user_id} | 
*FsAdUsersApi* | [**list_fsad_users**](docs/FsAdUsersApi.md#list_fsad_users) | **GET** /fs-ad-users/ | 
*FsArbitrationPoolsApi* | [**create_fs_arbitration_pool**](docs/FsArbitrationPoolsApi.md#create_fs_arbitration_pool) | **POST** /fs-arbitration-pools/ | 
*FsArbitrationPoolsApi* | [**delete_fs_arbitration_pool**](docs/FsArbitrationPoolsApi.md#delete_fs_arbitration_pool) | **DELETE** /fs-arbitration-pools/{fs_arbitration_pool_id} | 
*FsArbitrationPoolsApi* | [**get_fs_arbitration_pool**](docs/FsArbitrationPoolsApi.md#get_fs_arbitration_pool) | **GET** /fs-arbitration-pools/{fs_arbitration_pool_id} | 
*FsArbitrationPoolsApi* | [**list_fs_arbitration_pools**](docs/FsArbitrationPoolsApi.md#list_fs_arbitration_pools) | **GET** /fs-arbitration-pools/ | 
*FsArbitrationPoolsApi* | [**update_fs_arbitration_pool**](docs/FsArbitrationPoolsApi.md#update_fs_arbitration_pool) | **PATCH** /fs-arbitration-pools/{fs_arbitration_pool_id} | 
*FsClientGroupsApi* | [**add_fs_clients**](docs/FsClientGroupsApi.md#add_fs_clients) | **PUT** /fs-client-groups/{fs_client_group_id}/fs-clients | 
*FsClientGroupsApi* | [**create_fs_client_group**](docs/FsClientGroupsApi.md#create_fs_client_group) | **POST** /fs-client-groups/ | 
*FsClientGroupsApi* | [**delete_fs_client_group**](docs/FsClientGroupsApi.md#delete_fs_client_group) | **DELETE** /fs-client-groups/{fs_client_group_id} | 
*FsClientGroupsApi* | [**get_fs_client_group**](docs/FsClientGroupsApi.md#get_fs_client_group) | **GET** /fs-client-groups/{fs_client_group_id} | 
*FsClientGroupsApi* | [**list_fs_client_groups**](docs/FsClientGroupsApi.md#list_fs_client_groups) | **GET** /fs-client-groups/ | 
*FsClientGroupsApi* | [**remove_fs_clients**](docs/FsClientGroupsApi.md#remove_fs_clients) | **DELETE** /fs-client-groups/{fs_client_group_id}/fs-clients | 
*FsClientGroupsApi* | [**update_fs_client_group**](docs/FsClientGroupsApi.md#update_fs_client_group) | **PATCH** /fs-client-groups/{fs_client_group_id} | 
*FsClientsApi* | [**create_fs_client**](docs/FsClientsApi.md#create_fs_client) | **POST** /fs-clients/ | 
*FsClientsApi* | [**delete_fs_client**](docs/FsClientsApi.md#delete_fs_client) | **DELETE** /fs-clients/{fs_client_id} | 
*FsClientsApi* | [**get_fs_client**](docs/FsClientsApi.md#get_fs_client) | **GET** /fs-clients/{fs_client_id} | 
*FsClientsApi* | [**list_fs_clients**](docs/FsClientsApi.md#list_fs_clients) | **GET** /fs-clients/ | 
*FsClientsApi* | [**update_fs_client**](docs/FsClientsApi.md#update_fs_client) | **PATCH** /fs-clients/{fs_client_id} | 
*FsFoldersApi* | [**create_folder**](docs/FsFoldersApi.md#create_folder) | **POST** /fs-folders/ | 
*FsFoldersApi* | [**delete_folder**](docs/FsFoldersApi.md#delete_folder) | **DELETE** /fs-folders/{fs_folder_id} | 
*FsFoldersApi* | [**get_folder**](docs/FsFoldersApi.md#get_folder) | **GET** /fs-folders/{fs_folder_id} | 
*FsFoldersApi* | [**get_fs_folder_samples**](docs/FsFoldersApi.md#get_fs_folder_samples) | **GET** /fs-folders/{fs_folder_id}/samples | 
*FsFoldersApi* | [**list_folders**](docs/FsFoldersApi.md#list_folders) | **GET** /fs-folders/ | 
*FsFoldersApi* | [**roll_back_folder**](docs/FsFoldersApi.md#roll_back_folder) | **POST** /fs-folders/{fs_folder_id}:roll-back | 
*FsFoldersApi* | [**update_folder**](docs/FsFoldersApi.md#update_folder) | **PATCH** /fs-folders/{fs_folder_id} | 
*FsGatewayGroupsApi* | [**add_fs_gateways**](docs/FsGatewayGroupsApi.md#add_fs_gateways) | **PUT** /fs-gateway-groups/{fs_gateway_group_id}/fs-gateways | 
*FsGatewayGroupsApi* | [**create_fs_gateway_group**](docs/FsGatewayGroupsApi.md#create_fs_gateway_group) | **POST** /fs-gateway-groups/ | 
*FsGatewayGroupsApi* | [**delete_fs_gateway_group**](docs/FsGatewayGroupsApi.md#delete_fs_gateway_group) | **DELETE** /fs-gateway-groups/{fs_gateway_group_id} | 
*FsGatewayGroupsApi* | [**get_fs_gateway_group**](docs/FsGatewayGroupsApi.md#get_fs_gateway_group) | **GET** /fs-gateway-groups/{fs_gateway_group_id} | 
*FsGatewayGroupsApi* | [**list_fs_gateway_groups**](docs/FsGatewayGroupsApi.md#list_fs_gateway_groups) | **GET** /fs-gateway-groups/ | 
*FsGatewayGroupsApi* | [**remove_fs_gateways**](docs/FsGatewayGroupsApi.md#remove_fs_gateways) | **DELETE** /fs-gateway-groups/{fs_gateway_group_id}/fs-gateways | 
*FsGatewayGroupsApi* | [**update_fs_gateway_group**](docs/FsGatewayGroupsApi.md#update_fs_gateway_group) | **PATCH** /fs-gateway-groups/{fs_gateway_group_id} | 
*FsGatewaysApi* | [**get_fs_gateway**](docs/FsGatewaysApi.md#get_fs_gateway) | **GET** /fs-gateways/{fs_gateway_id} | 
*FsGatewaysApi* | [**list_fs_gateways**](docs/FsGatewaysApi.md#list_fs_gateways) | **GET** /fs-gateways/ | 
*FsLdapUsersApi* | [**get_fs_ldap_user**](docs/FsLdapUsersApi.md#get_fs_ldap_user) | **GET** /fs-ldap-users/{fs_ldap_user_id} | 
*FsLdapUsersApi* | [**list_fs_ldap_users**](docs/FsLdapUsersApi.md#list_fs_ldap_users) | **GET** /fs-ldap-users/ | 
*FsLdapsApi* | [**create_fs_ldap**](docs/FsLdapsApi.md#create_fs_ldap) | **POST** /fs-ldaps/ | 
*FsLdapsApi* | [**delete_fs_ldap**](docs/FsLdapsApi.md#delete_fs_ldap) | **DELETE** /fs-ldaps/{fs_ldap_id} | 
*FsLdapsApi* | [**get_fs_ldap**](docs/FsLdapsApi.md#get_fs_ldap) | **GET** /fs-ldaps/{fs_ldap_id} | 
*FsLdapsApi* | [**list_fs_ldaps**](docs/FsLdapsApi.md#list_fs_ldaps) | **GET** /fs-ldaps/ | 
*FsLdapsApi* | [**sync_fs_ldap**](docs/FsLdapsApi.md#sync_fs_ldap) | **POST** /fs-ldaps/{fs_ldap_id}:sync | 
*FsLdapsApi* | [**update_fs_ldap**](docs/FsLdapsApi.md#update_fs_ldap) | **PATCH** /fs-ldaps/{fs_ldap_id} | 
*FsShareAclsApi* | [**list_fs_share_ac_ls**](docs/FsShareAclsApi.md#list_fs_share_ac_ls) | **GET** /fs-share-acls/ | 
*FsShareMappingsApi* | [**list_fs_share_mappings**](docs/FsShareMappingsApi.md#list_fs_share_mappings) | **GET** /fs-share-mappings/ | 
*FsSharesApi* | [**add_fs_share_ac_ls**](docs/FsSharesApi.md#add_fs_share_ac_ls) | **PUT** /fs-shares/{fs_share_id}/fs-share-acls | 
*FsSharesApi* | [**create_fs_share**](docs/FsSharesApi.md#create_fs_share) | **POST** /fs-shares/ | 
*FsSharesApi* | [**delete_fs_share**](docs/FsSharesApi.md#delete_fs_share) | **DELETE** /fs-shares/{fs_share_id} | 
*FsSharesApi* | [**get_fs_share**](docs/FsSharesApi.md#get_fs_share) | **GET** /fs-shares/{fs_share_id} | 
*FsSharesApi* | [**list_fs_shares**](docs/FsSharesApi.md#list_fs_shares) | **GET** /fs-shares/ | 
*FsSharesApi* | [**remove_fs_share_ac_ls**](docs/FsSharesApi.md#remove_fs_share_ac_ls) | **DELETE** /fs-shares/{fs_share_id}/fs-share-acls | 
*FsSharesApi* | [**update_fs_share**](docs/FsSharesApi.md#update_fs_share) | **PATCH** /fs-shares/{fs_share_id} | 
*FsSnapshotsApi* | [**create_fs_snapshot**](docs/FsSnapshotsApi.md#create_fs_snapshot) | **POST** /fs-snapshots/ | 
*FsSnapshotsApi* | [**delete_fs_snapshot**](docs/FsSnapshotsApi.md#delete_fs_snapshot) | **DELETE** /fs-snapshots/{fs_snapshot_id} | 
*FsSnapshotsApi* | [**get_fs_snapshot**](docs/FsSnapshotsApi.md#get_fs_snapshot) | **GET** /fs-snapshots/{fs_snapshot_id} | 
*FsSnapshotsApi* | [**list_fs_snapshots**](docs/FsSnapshotsApi.md#list_fs_snapshots) | **GET** /fs-snapshots/ | 
*FsSnapshotsApi* | [**update_fs_snapshot**](docs/FsSnapshotsApi.md#update_fs_snapshot) | **PATCH** /fs-snapshots/{fs_snapshot_id} | 
*FsUsersApi* | [**create_fs_user**](docs/FsUsersApi.md#create_fs_user) | **POST** /fs-users/ | 
*FsUsersApi* | [**delete_fs_user**](docs/FsUsersApi.md#delete_fs_user) | **DELETE** /fs-users/{fs_user_id} | 
*FsUsersApi* | [**get_fs_user**](docs/FsUsersApi.md#get_fs_user) | **GET** /fs-users/{fs_user_id} | 
*FsUsersApi* | [**list_fs_users**](docs/FsUsersApi.md#list_fs_users) | **GET** /fs-users/ | 
*FsUsersApi* | [**update_fs_user**](docs/FsUsersApi.md#update_fs_user) | **PATCH** /fs-users/{fs_user_id} | 
*HostInfoApi* | [**get_host_info**](docs/HostInfoApi.md#get_host_info) | **GET** /host-info/ | 
*HostValidatorsApi* | [**create_host_validator**](docs/HostValidatorsApi.md#create_host_validator) | **POST** /host-validators/ | 
*HostValidatorsApi* | [**get_host_validator**](docs/HostValidatorsApi.md#get_host_validator) | **GET** /host-validators/{host_validator_id} | 
*HostsApi* | [**create_host**](docs/HostsApi.md#create_host) | **POST** /hosts/ | 
*HostsApi* | [**delete_host**](docs/HostsApi.md#delete_host) | **DELETE** /hosts/{host_id} | 
*HostsApi* | [**get_host**](docs/HostsApi.md#get_host) | **GET** /hosts/{host_id} | 
*HostsApi* | [**get_host_samples**](docs/HostsApi.md#get_host_samples) | **GET** /hosts/{host_id}/samples | 
*HostsApi* | [**list_hosts**](docs/HostsApi.md#list_hosts) | **GET** /hosts/ | 
*HostsApi* | [**update_host**](docs/HostsApi.md#update_host) | **PATCH** /hosts/{host_id} | 
*IdentityPlatformsApi* | [**create_identity_platform**](docs/IdentityPlatformsApi.md#create_identity_platform) | **POST** /identity-platforms/ | 
*IdentityPlatformsApi* | [**delete_identity_platform**](docs/IdentityPlatformsApi.md#delete_identity_platform) | **DELETE** /identity-platforms/{identity_platform_id} | 
*IdentityPlatformsApi* | [**get_identity_platform**](docs/IdentityPlatformsApi.md#get_identity_platform) | **GET** /identity-platforms/{identity_platform_id} | 
*IdentityPlatformsApi* | [**list_identity_platforms**](docs/IdentityPlatformsApi.md#list_identity_platforms) | **GET** /identity-platforms/ | 
*IdentityPlatformsApi* | [**regenerate_identity_key**](docs/IdentityPlatformsApi.md#regenerate_identity_key) | **POST** /identity-platforms/{identity_platform_id}:regenerate | 
*IdentityPlatformsApi* | [**update_identity_platform**](docs/IdentityPlatformsApi.md#update_identity_platform) | **PATCH** /identity-platforms/{identity_platform_id} | 
*LicensesApi* | [**download_license_key**](docs/LicensesApi.md#download_license_key) | **GET** /licenses/key | 
*LicensesApi* | [**get_active_license**](docs/LicensesApi.md#get_active_license) | **GET** /licenses/license | 
*LicensesApi* | [**get_license**](docs/LicensesApi.md#get_license) | **GET** /licenses/{license_id} | 
*LicensesApi* | [**list_licenses**](docs/LicensesApi.md#list_licenses) | **GET** /licenses/ | 
*LicensesApi* | [**register_license**](docs/LicensesApi.md#register_license) | **POST** /licenses/ | 
*LunsApi* | [**get_lun**](docs/LunsApi.md#get_lun) | **GET** /luns/{lun_id} | 
*LunsApi* | [**list_luns**](docs/LunsApi.md#list_luns) | **GET** /luns/ | 
*MappingGroupsApi* | [**add_volumes**](docs/MappingGroupsApi.md#add_volumes) | **POST** /mapping-groups/{mapping_group_id}/block-volumes | 
*MappingGroupsApi* | [**create_mapping_group**](docs/MappingGroupsApi.md#create_mapping_group) | **POST** /mapping-groups/ | 
*MappingGroupsApi* | [**delete_mapping_group**](docs/MappingGroupsApi.md#delete_mapping_group) | **DELETE** /mapping-groups/{mapping_group_id} | 
*MappingGroupsApi* | [**get_mapping_group**](docs/MappingGroupsApi.md#get_mapping_group) | **GET** /mapping-groups/{mapping_group_id} | 
*MappingGroupsApi* | [**list_mapping_groups**](docs/MappingGroupsApi.md#list_mapping_groups) | **GET** /mapping-groups/ | 
*MappingGroupsApi* | [**remove_volumes**](docs/MappingGroupsApi.md#remove_volumes) | **DELETE** /mapping-groups/{mapping_group_id}/block-volumes | 
*MappingGroupsApi* | [**update_client_group**](docs/MappingGroupsApi.md#update_client_group) | **PATCH** /mapping-groups/{mapping_group_id}/client-group | 
*MappingGroupsApi* | [**update_mapping_group**](docs/MappingGroupsApi.md#update_mapping_group) | **PATCH** /mapping-groups/{mapping_group_id} | 
*NetworkAddressesApi* | [**get_network_address**](docs/NetworkAddressesApi.md#get_network_address) | **GET** /network-addresses/{network_address_id} | 
*NetworkAddressesApi* | [**list_network_addresses**](docs/NetworkAddressesApi.md#list_network_addresses) | **GET** /network-addresses/ | 
*NetworkInterfacesApi* | [**get_network_interface**](docs/NetworkInterfacesApi.md#get_network_interface) | **GET** /network-interfaces/{network_interface_id} | 
*NetworkInterfacesApi* | [**get_network_interface_samples**](docs/NetworkInterfacesApi.md#get_network_interface_samples) | **GET** /network-interfaces/{network_interface_id}/samples | 
*NetworkInterfacesApi* | [**list_network_interfaces**](docs/NetworkInterfacesApi.md#list_network_interfaces) | **GET** /network-interfaces/ | 
*NfsGatewayBucketMapsApi* | [**list_nfs_gateway_s3_bucket_maps**](docs/NfsGatewayBucketMapsApi.md#list_nfs_gateway_s3_bucket_maps) | **GET** /nfs-gateway-bucket-maps/ | 
*NfsGatewaysApi* | [**create_nfs_gateway**](docs/NfsGatewaysApi.md#create_nfs_gateway) | **POST** /nfs-gateways/ | 
*NfsGatewaysApi* | [**create_nfs_gateway_bucket_map**](docs/NfsGatewaysApi.md#create_nfs_gateway_bucket_map) | **PUT** /nfs-gateways/{gateway_id}/buckets/{bucket_id} | 
*NfsGatewaysApi* | [**delete_nfs_gateway**](docs/NfsGatewaysApi.md#delete_nfs_gateway) | **DELETE** /nfs-gateways/{gateway_id} | 
*NfsGatewaysApi* | [**delete_nfs_gateway_bucket_map**](docs/NfsGatewaysApi.md#delete_nfs_gateway_bucket_map) | **DELETE** /nfs-gateways/{gateway_id}/buckets/{bucket_id} | 
*NfsGatewaysApi* | [**do_nfs_gateway**](docs/NfsGatewaysApi.md#do_nfs_gateway) | **PUT** /nfs-gateways/{gateway_id} | 
*NfsGatewaysApi* | [**get_nfs_gateway**](docs/NfsGatewaysApi.md#get_nfs_gateway) | **GET** /nfs-gateways/{gateway_id} | 
*NfsGatewaysApi* | [**get_nfs_gateway_bucket_map**](docs/NfsGatewaysApi.md#get_nfs_gateway_bucket_map) | **GET** /nfs-gateways/{gateway_id}/buckets/{bucket_id} | 
*NfsGatewaysApi* | [**get_nfs_gateway_samples**](docs/NfsGatewaysApi.md#get_nfs_gateway_samples) | **GET** /nfs-gateways/{gateway_id}/samples | 
*NfsGatewaysApi* | [**list_nfs_gateway_bucket_maps**](docs/NfsGatewaysApi.md#list_nfs_gateway_bucket_maps) | **GET** /nfs-gateways/{gateway_id}/buckets | 
*NfsGatewaysApi* | [**list_nfs_gateways**](docs/NfsGatewaysApi.md#list_nfs_gateways) | **GET** /nfs-gateways/ | 
*NfsGatewaysApi* | [**update_nfs_gateway**](docs/NfsGatewaysApi.md#update_nfs_gateway) | **PATCH** /nfs-gateways/{gateway_id} | 
*NfsGatewaysApi* | [**update_nfs_gateway_bucket_map**](docs/NfsGatewaysApi.md#update_nfs_gateway_bucket_map) | **PATCH** /nfs-gateways/{gateway_id}/buckets/{bucket_id} | 
*OsArchivePoolsApi* | [**create_archive_pool**](docs/OsArchivePoolsApi.md#create_archive_pool) | **POST** /os-archive-pools/ | 
*OsArchivePoolsApi* | [**delete_archive_pool**](docs/OsArchivePoolsApi.md#delete_archive_pool) | **DELETE** /os-archive-pools/{archive_pool_id} | 
*OsArchivePoolsApi* | [**get_archive_pool**](docs/OsArchivePoolsApi.md#get_archive_pool) | **GET** /os-archive-pools/{archive_pool_id} | 
*OsArchivePoolsApi* | [**list_archive_pools**](docs/OsArchivePoolsApi.md#list_archive_pools) | **GET** /os-archive-pools/ | 
*OsArchivePoolsApi* | [**update_archive_pool**](docs/OsArchivePoolsApi.md#update_archive_pool) | **PATCH** /os-archive-pools/{archive_pool_id} | 
*OsBucketsApi* | [**batch_get_object_storage_samples**](docs/OsBucketsApi.md#batch_get_object_storage_samples) | **GET** /os-buckets/samples | 
*OsBucketsApi* | [**create_bucket**](docs/OsBucketsApi.md#create_bucket) | **POST** /os-buckets/ | 
*OsBucketsApi* | [**create_object_storage_bucket_nfs_clients**](docs/OsBucketsApi.md#create_object_storage_bucket_nfs_clients) | **POST** /os-buckets/{bucket_id}/nfs-clients | 
*OsBucketsApi* | [**delete_bucket**](docs/OsBucketsApi.md#delete_bucket) | **DELETE** /os-buckets/{bucket_id} | 
*OsBucketsApi* | [**delete_object_storage_bucket_nfs_clients**](docs/OsBucketsApi.md#delete_object_storage_bucket_nfs_clients) | **DELETE** /os-buckets/{bucket_id}/nfs-clients | 
*OsBucketsApi* | [**delete_object_storage_lifecycle**](docs/OsBucketsApi.md#delete_object_storage_lifecycle) | **DELETE** /os-buckets/{bucket_id}/lifecycle | 
*OsBucketsApi* | [**get_bucket**](docs/OsBucketsApi.md#get_bucket) | **GET** /os-buckets/{bucket_id} | 
*OsBucketsApi* | [**get_object_storage_bucket_nfs_client**](docs/OsBucketsApi.md#get_object_storage_bucket_nfs_client) | **GET** /os-buckets/{bucket_id}/nfs-clients/{client_id} | 
*OsBucketsApi* | [**get_object_storage_bucket_samples**](docs/OsBucketsApi.md#get_object_storage_bucket_samples) | **GET** /os-buckets/{bucket_id}/samples | 
*OsBucketsApi* | [**list_buckets**](docs/OsBucketsApi.md#list_buckets) | **GET** /os-buckets/ | 
*OsBucketsApi* | [**list_object_storage_bucket_nfs_clients**](docs/OsBucketsApi.md#list_object_storage_bucket_nfs_clients) | **GET** /os-buckets/{bucket_id}/nfs-clients | 
*OsBucketsApi* | [**set_object_storage_lifecycle_rules**](docs/OsBucketsApi.md#set_object_storage_lifecycle_rules) | **PUT** /os-buckets/{bucket_id}/lifecycle | 
*OsBucketsApi* | [**update_bucket**](docs/OsBucketsApi.md#update_bucket) | **PATCH** /os-buckets/{bucket_id} | 
*OsBucketsApi* | [**update_object_storage_bucket_nfs_client**](docs/OsBucketsApi.md#update_object_storage_bucket_nfs_client) | **PATCH** /os-buckets/{bucket_id}/nfs-clients/{client_id} | 
*OsGatewaysApi* | [**create_gateway**](docs/OsGatewaysApi.md#create_gateway) | **POST** /os-gateways/ | 
*OsGatewaysApi* | [**delete_gateway**](docs/OsGatewaysApi.md#delete_gateway) | **DELETE** /os-gateways/{gateway_id} | 
*OsGatewaysApi* | [**get_gateway**](docs/OsGatewaysApi.md#get_gateway) | **GET** /os-gateways/{gateway_id} | 
*OsGatewaysApi* | [**get_gateway_samples**](docs/OsGatewaysApi.md#get_gateway_samples) | **GET** /os-gateways/{gateway_id}/samples | 
*OsGatewaysApi* | [**list_gateways**](docs/OsGatewaysApi.md#list_gateways) | **GET** /os-gateways/ | 
*OsGatewaysApi* | [**update_gateway**](docs/OsGatewaysApi.md#update_gateway) | **PUT** /os-gateways/{gateway_id} | 
*OsKeysApi* | [**create_key**](docs/OsKeysApi.md#create_key) | **POST** /os-keys/ | 
*OsKeysApi* | [**delete_key**](docs/OsKeysApi.md#delete_key) | **DELETE** /os-keys/{key_id} | 
*OsKeysApi* | [**get_key**](docs/OsKeysApi.md#get_key) | **GET** /os-keys/{key_id} | 
*OsKeysApi* | [**list_keys**](docs/OsKeysApi.md#list_keys) | **GET** /os-keys/ | 
*OsKeysApi* | [**update_key**](docs/OsKeysApi.md#update_key) | **PATCH** /os-keys/{key_id} | 
*OsLifecyclesApi* | [**get_lifecycle**](docs/OsLifecyclesApi.md#get_lifecycle) | **GET** /os-lifecycles/{lifecycle_id} | 
*OsLifecyclesApi* | [**list_lifecycles**](docs/OsLifecyclesApi.md#list_lifecycles) | **GET** /os-lifecycles/ | 
*OsPoliciesApi* | [**create_policy**](docs/OsPoliciesApi.md#create_policy) | **POST** /os-policies/ | 
*OsPoliciesApi* | [**delete_policy**](docs/OsPoliciesApi.md#delete_policy) | **DELETE** /os-policies/{policy_id} | 
*OsPoliciesApi* | [**get_policy**](docs/OsPoliciesApi.md#get_policy) | **GET** /os-policies/{policy_id} | 
*OsPoliciesApi* | [**list_policies**](docs/OsPoliciesApi.md#list_policies) | **GET** /os-policies/ | 
*OsPoliciesApi* | [**update_policy**](docs/OsPoliciesApi.md#update_policy) | **PATCH** /os-policies/{policy_id} | 
*OsReplicationPoliciesApi* | [**create_object_storage_replication_policy**](docs/OsReplicationPoliciesApi.md#create_object_storage_replication_policy) | **POST** /os-replication-policies/ | 
*OsReplicationPoliciesApi* | [**delete_object_storage_replication_policy**](docs/OsReplicationPoliciesApi.md#delete_object_storage_replication_policy) | **DELETE** /os-replication-policies/{policy_id} | 
*OsReplicationPoliciesApi* | [**get_object_storage_replication_policy**](docs/OsReplicationPoliciesApi.md#get_object_storage_replication_policy) | **GET** /os-replication-policies/{policy_id} | 
*OsReplicationPoliciesApi* | [**list_object_storage_replication_policies**](docs/OsReplicationPoliciesApi.md#list_object_storage_replication_policies) | **GET** /os-replication-policies/ | 
*OsUsersApi* | [**create_object_storage_user**](docs/OsUsersApi.md#create_object_storage_user) | **POST** /os-users/ | 
*OsUsersApi* | [**delete_object_storage_user**](docs/OsUsersApi.md#delete_object_storage_user) | **DELETE** /os-users/{user_id} | 
*OsUsersApi* | [**get_object_storage_user**](docs/OsUsersApi.md#get_object_storage_user) | **GET** /os-users/{user_id} | 
*OsUsersApi* | [**get_object_storage_user_samples**](docs/OsUsersApi.md#get_object_storage_user_samples) | **GET** /os-users/{user_id}/samples | 
*OsUsersApi* | [**list_object_storage_users**](docs/OsUsersApi.md#list_object_storage_users) | **GET** /os-users/ | 
*OsUsersApi* | [**update_object_storage_user**](docs/OsUsersApi.md#update_object_storage_user) | **PATCH** /os-users/{user_id} | 
*OsZonesApi* | [**create_object_storage_zone**](docs/OsZonesApi.md#create_object_storage_zone) | **POST** /os-zones/ | 
*OsZonesApi* | [**delete_object_storage_zone**](docs/OsZonesApi.md#delete_object_storage_zone) | **DELETE** /os-zones/{zone_id} | 
*OsZonesApi* | [**get_object_storage_zone**](docs/OsZonesApi.md#get_object_storage_zone) | **GET** /os-zones/{zone_id} | 
*OsZonesApi* | [**list_object_storage_zones**](docs/OsZonesApi.md#list_object_storage_zones) | **GET** /os-zones/ | 
*OsZonesApi* | [**switch_to_master**](docs/OsZonesApi.md#switch_to_master) | **POST** /os-zones/{zone_id}:switch-to-master | 
*OsZonesApi* | [**update_object_storage_zone**](docs/OsZonesApi.md#update_object_storage_zone) | **PATCH** /os-zones/{zone_id} | 
*OsdsApi* | [**create_osd**](docs/OsdsApi.md#create_osd) | **POST** /osds/ | 
*OsdsApi* | [**delete_osd**](docs/OsdsApi.md#delete_osd) | **DELETE** /osds/{osd_id} | 
*OsdsApi* | [**get_chunks**](docs/OsdsApi.md#get_chunks) | **GET** /osds/{osd_id}/chunks | 
*OsdsApi* | [**get_osd**](docs/OsdsApi.md#get_osd) | **GET** /osds/{osd_id} | 
*OsdsApi* | [**get_osd_predictions**](docs/OsdsApi.md#get_osd_predictions) | **GET** /osds/{osd_id}/predictions | 
*OsdsApi* | [**get_osd_samples**](docs/OsdsApi.md#get_osd_samples) | **GET** /osds/{osd_id}/samples | 
*OsdsApi* | [**list_osds**](docs/OsdsApi.md#list_osds) | **GET** /osds/ | 
*OsdsApi* | [**maintain_osd**](docs/OsdsApi.md#maintain_osd) | **POST** /osds/{osd_id}:maintain | 
*OsdsApi* | [**unmaintain_osd**](docs/OsdsApi.md#unmaintain_osd) | **POST** /osds/{osd_id}:unmaintain | 
*OsdsApi* | [**update_osd**](docs/OsdsApi.md#update_osd) | **PATCH** /osds/{osd_id} | 
*PlacementNodesApi* | [**create_placement_node**](docs/PlacementNodesApi.md#create_placement_node) | **POST** /placement-nodes/ | 
*PlacementNodesApi* | [**delete_placement_node**](docs/PlacementNodesApi.md#delete_placement_node) | **DELETE** /placement-nodes/{placement_node_id} | 
*PlacementNodesApi* | [**get_placement_node**](docs/PlacementNodesApi.md#get_placement_node) | **GET** /placement-nodes/{placement_node_id} | 
*PlacementNodesApi* | [**get_placement_node_topology**](docs/PlacementNodesApi.md#get_placement_node_topology) | **GET** /placement-nodes/{placement_node_id}/topology | 
*PlacementNodesApi* | [**update_placement_node**](docs/PlacementNodesApi.md#update_placement_node) | **PATCH** /placement-nodes/{placement_node_id} | 
*PoolsApi* | [**add_osds_to_pool**](docs/PoolsApi.md#add_osds_to_pool) | **PUT** /pools/{pool_id}/osds | 
*PoolsApi* | [**create_pool**](docs/PoolsApi.md#create_pool) | **POST** /pools/ | 
*PoolsApi* | [**delete_pool**](docs/PoolsApi.md#delete_pool) | **DELETE** /pools/{pool_id} | 
*PoolsApi* | [**get_pool**](docs/PoolsApi.md#get_pool) | **GET** /pools/{pool_id} | 
*PoolsApi* | [**get_pool_predictions**](docs/PoolsApi.md#get_pool_predictions) | **GET** /pools/{pool_id}/predictions | 
*PoolsApi* | [**get_pool_samples**](docs/PoolsApi.md#get_pool_samples) | **GET** /pools/{pool_id}/samples | 
*PoolsApi* | [**get_pool_topology**](docs/PoolsApi.md#get_pool_topology) | **GET** /pools/{pool_id}/topology | 
*PoolsApi* | [**list_pools**](docs/PoolsApi.md#list_pools) | **GET** /pools/ | 
*PoolsApi* | [**remove_osds_from_pool**](docs/PoolsApi.md#remove_osds_from_pool) | **DELETE** /pools/{pool_id}/osds | 
*PoolsApi* | [**reweight_pool**](docs/PoolsApi.md#reweight_pool) | **POST** /pools/{pool_id}:reweight | 
*PoolsApi* | [**update_pool**](docs/PoolsApi.md#update_pool) | **PATCH** /pools/{pool_id} | 
*ProtectionDomainsApi* | [**get_protection_domain**](docs/ProtectionDomainsApi.md#get_protection_domain) | **GET** /protection-domains/{protection_domain_id} | 
*ProtectionDomainsApi* | [**list_protection_domains**](docs/ProtectionDomainsApi.md#list_protection_domains) | **GET** /protection-domains/ | 
*RemoteClustersApi* | [**create_remote_cluster**](docs/RemoteClustersApi.md#create_remote_cluster) | **POST** /remote-clusters/ | 
*RemoteClustersApi* | [**delete_remote_cluster**](docs/RemoteClustersApi.md#delete_remote_cluster) | **DELETE** /remote-clusters/{cluster_id} | 
*RemoteClustersApi* | [**get_remote_cluster**](docs/RemoteClustersApi.md#get_remote_cluster) | **GET** /remote-clusters/{cluster_id} | 
*RemoteClustersApi* | [**list_remote_clusters**](docs/RemoteClustersApi.md#list_remote_clusters) | **GET** /remote-clusters/ | 
*RemoteClustersApi* | [**update_remote_cluster**](docs/RemoteClustersApi.md#update_remote_cluster) | **PATCH** /remote-clusters/{cluster_id} | 
*RoleMappingsApi* | [**create_role_mapping**](docs/RoleMappingsApi.md#create_role_mapping) | **POST** /role-mappings/ | 
*RoleMappingsApi* | [**delete_role_mapping**](docs/RoleMappingsApi.md#delete_role_mapping) | **DELETE** /role-mappings/{role_mapping_id} | 
*RoleMappingsApi* | [**get_role_mapping**](docs/RoleMappingsApi.md#get_role_mapping) | **GET** /role-mappings/{role_mapping_id} | 
*RoleMappingsApi* | [**list_role_mappings**](docs/RoleMappingsApi.md#list_role_mappings) | **GET** /role-mappings/ | 
*RoleMappingsApi* | [**update_role_mapping**](docs/RoleMappingsApi.md#update_role_mapping) | **PATCH** /role-mappings/{role_mapping_id} | 
*S3LoadBalancerGroupsApi* | [**add_s3_load_blancers_to_group**](docs/S3LoadBalancerGroupsApi.md#add_s3_load_blancers_to_group) | **PUT** /s3-load-balancer-groups/{group_id}/s3-load-balancers | 
*S3LoadBalancerGroupsApi* | [**create_s3_load_balancer_group**](docs/S3LoadBalancerGroupsApi.md#create_s3_load_balancer_group) | **POST** /s3-load-balancer-groups/ | 
*S3LoadBalancerGroupsApi* | [**delete_s3_load_balancer_group**](docs/S3LoadBalancerGroupsApi.md#delete_s3_load_balancer_group) | **DELETE** /s3-load-balancer-groups/{group_id} | 
*S3LoadBalancerGroupsApi* | [**get_s3_load_balancer_group**](docs/S3LoadBalancerGroupsApi.md#get_s3_load_balancer_group) | **GET** /s3-load-balancer-groups/{group_id} | 
*S3LoadBalancerGroupsApi* | [**list_s3_load_balancer_groups**](docs/S3LoadBalancerGroupsApi.md#list_s3_load_balancer_groups) | **GET** /s3-load-balancer-groups/ | 
*S3LoadBalancerGroupsApi* | [**remove_s3_load_blancers_from_group**](docs/S3LoadBalancerGroupsApi.md#remove_s3_load_blancers_from_group) | **DELETE** /s3-load-balancer-groups/{group_id}/s3-load-balancers | 
*S3LoadBalancerGroupsApi* | [**update_s3_load_balancer_group**](docs/S3LoadBalancerGroupsApi.md#update_s3_load_balancer_group) | **PATCH** /s3-load-balancer-groups/{group_id} | 
*S3LoadBalancersApi* | [**batch_get_s3_load_balancer_samples**](docs/S3LoadBalancersApi.md#batch_get_s3_load_balancer_samples) | **GET** /s3-load-balancers/samples | 
*S3LoadBalancersApi* | [**get_s3_load_balancer**](docs/S3LoadBalancersApi.md#get_s3_load_balancer) | **GET** /s3-load-balancers/{load_balancer_id} | 
*S3LoadBalancersApi* | [**get_s3_load_balancer_samples**](docs/S3LoadBalancersApi.md#get_s3_load_balancer_samples) | **GET** /s3-load-balancers/{s3_load_balancer_id}/samples | 
*S3LoadBalancersApi* | [**list_s3_load_balancers**](docs/S3LoadBalancersApi.md#list_s3_load_balancers) | **GET** /s3-load-balancers/ | 
*SearchApi* | [**search**](docs/SearchApi.md#search) | **GET** /search/{type} | 
*SearchCapabilitiesApi* | [**search_capabilites**](docs/SearchCapabilitiesApi.md#search_capabilites) | **GET** /search-capabilities/ | 
*ServicesApi* | [**get_service**](docs/ServicesApi.md#get_service) | **GET** /services/{service_id} | 
*ServicesApi* | [**list_services**](docs/ServicesApi.md#list_services) | **GET** /services/ | 
*SnmpApi* | [**download_mib**](docs/SnmpApi.md#download_mib) | **GET** /snmp/mib | 
*SnmpApi* | [**get_snmp**](docs/SnmpApi.md#get_snmp) | **GET** /snmp/ | 
*SnmpApi* | [**set_snmp**](docs/SnmpApi.md#set_snmp) | **PATCH** /snmp/ | 
*SslCertificatesApi* | [**create_ssl_certificate**](docs/SslCertificatesApi.md#create_ssl_certificate) | **POST** /ssl-certificates/ | 
*SslCertificatesApi* | [**delete_ssl_certificate**](docs/SslCertificatesApi.md#delete_ssl_certificate) | **DELETE** /ssl-certificates/{certificate_id} | 
*SslCertificatesApi* | [**get_ssl_certificate**](docs/SslCertificatesApi.md#get_ssl_certificate) | **GET** /ssl-certificates/{certificate_id} | 
*SslCertificatesApi* | [**list_ssl_certificates**](docs/SslCertificatesApi.md#list_ssl_certificates) | **GET** /ssl-certificates/ | 
*SslCertificatesApi* | [**update_ssl_certificate**](docs/SslCertificatesApi.md#update_ssl_certificate) | **PATCH** /ssl-certificates/{certificate_id} | 
*SystemLogsApi* | [**download_system_logs**](docs/SystemLogsApi.md#download_system_logs) | **GET** /system-logs/archive | 
*SystemLogsApi* | [**list_system_logs**](docs/SystemLogsApi.md#list_system_logs) | **GET** /system-logs/ | 
*TargetsApi* | [**create_target**](docs/TargetsApi.md#create_target) | **POST** /targets/ | 
*TargetsApi* | [**delete_target**](docs/TargetsApi.md#delete_target) | **DELETE** /targets/{target_id} | 
*TargetsApi* | [**list_targets**](docs/TargetsApi.md#list_targets) | **GET** /targets/ | 
*TasksApi* | [**get_task**](docs/TasksApi.md#get_task) | **GET** /tasks/{task_id} | 
*TasksApi* | [**list_tasks**](docs/TasksApi.md#list_tasks) | **GET** /tasks/ | 
*UsersApi* | [**change_password**](docs/UsersApi.md#change_password) | **PUT** /users/{user_id}/password | 
*UsersApi* | [**create_user**](docs/UsersApi.md#create_user) | **POST** /users/ | 
*UsersApi* | [**delete_user**](docs/UsersApi.md#delete_user) | **DELETE** /users/{user_id} | 
*UsersApi* | [**get_user**](docs/UsersApi.md#get_user) | **GET** /users/{user_id} | 
*UsersApi* | [**get_user_settings**](docs/UsersApi.md#get_user_settings) | **GET** /users/{user_id}/settings | 
*UsersApi* | [**list_users**](docs/UsersApi.md#list_users) | **GET** /users/ | 
*UsersApi* | [**update_user**](docs/UsersApi.md#update_user) | **PATCH** /users/{user_id} | 
*UsersApi* | [**update_user_0**](docs/UsersApi.md#update_user_0) | **PATCH** /users/{user_id}/settings | 
*VersionApi* | [**get_version**](docs/VersionApi.md#get_version) | **GET** /version/ | 


## Documentation For Models

 - [AccessPath](docs/AccessPath.md)
 - [AccessPathCreateReq](docs/AccessPathCreateReq.md)
 - [AccessPathCreateReqAccessPath](docs/AccessPathCreateReqAccessPath.md)
 - [AccessPathNestview](docs/AccessPathNestview.md)
 - [AccessPathResp](docs/AccessPathResp.md)
 - [AccessPathUpdateReq](docs/AccessPathUpdateReq.md)
 - [AccessPathUpdateReqAccessPath](docs/AccessPathUpdateReqAccessPath.md)
 - [AccessPathsResp](docs/AccessPathsResp.md)
 - [AccessToken](docs/AccessToken.md)
 - [AccessTokenCreateReq](docs/AccessTokenCreateReq.md)
 - [AccessTokenCreateReqAccessToken](docs/AccessTokenCreateReqAccessToken.md)
 - [AccessTokenCreateResp](docs/AccessTokenCreateResp.md)
 - [AccessTokenResp](docs/AccessTokenResp.md)
 - [AccessTokensResp](docs/AccessTokensResp.md)
 - [ActionLog](docs/ActionLog.md)
 - [ActionLogsResp](docs/ActionLogsResp.md)
 - [Alert](docs/Alert.md)
 - [AlertActionReq](docs/AlertActionReq.md)
 - [AlertActionReqAlert](docs/AlertActionReqAlert.md)
 - [AlertGroup](docs/AlertGroup.md)
 - [AlertGroupCreateReq](docs/AlertGroupCreateReq.md)
 - [AlertGroupCreateReqAlertGroup](docs/AlertGroupCreateReqAlertGroup.md)
 - [AlertGroupResp](docs/AlertGroupResp.md)
 - [AlertGroupUpdateReq](docs/AlertGroupUpdateReq.md)
 - [AlertGroupUpdateReqAlertGroup](docs/AlertGroupUpdateReqAlertGroup.md)
 - [AlertGroupsResp](docs/AlertGroupsResp.md)
 - [AlertResp](docs/AlertResp.md)
 - [AlertRule](docs/AlertRule.md)
 - [AlertRuleCreateReq](docs/AlertRuleCreateReq.md)
 - [AlertRuleCreateReqRule](docs/AlertRuleCreateReqRule.md)
 - [AlertRuleResp](docs/AlertRuleResp.md)
 - [AlertRuleSchema](docs/AlertRuleSchema.md)
 - [AlertRuleSchemaResp](docs/AlertRuleSchemaResp.md)
 - [AlertRuleUpdateReq](docs/AlertRuleUpdateReq.md)
 - [AlertRuleUpdateReqRule](docs/AlertRuleUpdateReqRule.md)
 - [AlertRulesResp](docs/AlertRulesResp.md)
 - [AlertStats](docs/AlertStats.md)
 - [AlertStatsResp](docs/AlertStatsResp.md)
 - [AlertsActionReq](docs/AlertsActionReq.md)
 - [AlertsActionReqAlerts](docs/AlertsActionReqAlerts.md)
 - [AlertsResp](docs/AlertsResp.md)
 - [AuthLoginReq](docs/AuthLoginReq.md)
 - [AuthLoginReqAuth](docs/AuthLoginReqAuth.md)
 - [AuthPasswordReq](docs/AuthPasswordReq.md)
 - [AuthPasswordReqUser](docs/AuthPasswordReqUser.md)
 - [AuthTokenReq](docs/AuthTokenReq.md)
 - [BlockReplicationConfig](docs/BlockReplicationConfig.md)
 - [BootNode](docs/BootNode.md)
 - [BootNodeReq](docs/BootNodeReq.md)
 - [BootNodeReqBootNode](docs/BootNodeReqBootNode.md)
 - [BootNodeResp](docs/BootNodeResp.md)
 - [BucketFlag](docs/BucketFlag.md)
 - [BucketFlagReq](docs/BucketFlagReq.md)
 - [ChangePasswordReq](docs/ChangePasswordReq.md)
 - [ChangePasswordReqReq](docs/ChangePasswordReqReq.md)
 - [ChunksResp](docs/ChunksResp.md)
 - [Client](docs/Client.md)
 - [ClientCode](docs/ClientCode.md)
 - [ClientCodesResp](docs/ClientCodesResp.md)
 - [ClientGroup](docs/ClientGroup.md)
 - [ClientGroupCreateReq](docs/ClientGroupCreateReq.md)
 - [ClientGroupCreateReqClientGroup](docs/ClientGroupCreateReqClientGroup.md)
 - [ClientGroupCreateReqClientGroupClientsElt](docs/ClientGroupCreateReqClientGroupClientsElt.md)
 - [ClientGroupNestview](docs/ClientGroupNestview.md)
 - [ClientGroupResp](docs/ClientGroupResp.md)
 - [ClientGroupUpdateReq](docs/ClientGroupUpdateReq.md)
 - [ClientGroupUpdateReqClientGroup](docs/ClientGroupUpdateReqClientGroup.md)
 - [ClientGroupUpdateReqClientGroupClientsElt](docs/ClientGroupUpdateReqClientGroupClientsElt.md)
 - [ClientGroupsResp](docs/ClientGroupsResp.md)
 - [ClientLunMapping](docs/ClientLunMapping.md)
 - [ClientLunMappingResp](docs/ClientLunMappingResp.md)
 - [ClientLunMappingsResp](docs/ClientLunMappingsResp.md)
 - [CloudDatacenterNestview](docs/CloudDatacenterNestview.md)
 - [CloudExtraProperties](docs/CloudExtraProperties.md)
 - [CloudInstance](docs/CloudInstance.md)
 - [CloudInstanceNestview](docs/CloudInstanceNestview.md)
 - [CloudInstanceResp](docs/CloudInstanceResp.md)
 - [CloudInstanceSamplesResp](docs/CloudInstanceSamplesResp.md)
 - [CloudInstanceStat](docs/CloudInstanceStat.md)
 - [CloudInstancesResp](docs/CloudInstancesResp.md)
 - [CloudPlatform](docs/CloudPlatform.md)
 - [CloudPlatformCreateReq](docs/CloudPlatformCreateReq.md)
 - [CloudPlatformCreateReqPlatform](docs/CloudPlatformCreateReqPlatform.md)
 - [CloudPlatformNestview](docs/CloudPlatformNestview.md)
 - [CloudPlatformResp](docs/CloudPlatformResp.md)
 - [CloudPlatformUpdateReq](docs/CloudPlatformUpdateReq.md)
 - [CloudPlatformUpdateReqPlatform](docs/CloudPlatformUpdateReqPlatform.md)
 - [CloudPlatformsResp](docs/CloudPlatformsResp.md)
 - [CloudVolume](docs/CloudVolume.md)
 - [CloudVolumeAttachment](docs/CloudVolumeAttachment.md)
 - [CloudVolumeAttachmentsResp](docs/CloudVolumeAttachmentsResp.md)
 - [CloudVolumeNestview](docs/CloudVolumeNestview.md)
 - [CloudVolumeResp](docs/CloudVolumeResp.md)
 - [CloudVolumesResp](docs/CloudVolumesResp.md)
 - [Cluster](docs/Cluster.md)
 - [ClusterInstallation](docs/ClusterInstallation.md)
 - [ClusterInstallationResp](docs/ClusterInstallationResp.md)
 - [ClusterInstallationSteps](docs/ClusterInstallationSteps.md)
 - [ClusterMaintainReq](docs/ClusterMaintainReq.md)
 - [ClusterMaintainReqCluster](docs/ClusterMaintainReqCluster.md)
 - [ClusterOverview](docs/ClusterOverview.md)
 - [ClusterOverviewResp](docs/ClusterOverviewResp.md)
 - [ClusterRecordResp](docs/ClusterRecordResp.md)
 - [ClusterResp](docs/ClusterResp.md)
 - [ClusterSamplesResp](docs/ClusterSamplesResp.md)
 - [ClusterServerTimeResp](docs/ClusterServerTimeResp.md)
 - [ClusterSetAccessInfoReq](docs/ClusterSetAccessInfoReq.md)
 - [ClusterSetAccessInfoReqCluster](docs/ClusterSetAccessInfoReqCluster.md)
 - [ClusterStat](docs/ClusterStat.md)
 - [ClusterStatsPredictionResp](docs/ClusterStatsPredictionResp.md)
 - [ClusterUpdateReq](docs/ClusterUpdateReq.md)
 - [ClusterUpdateReqCluster](docs/ClusterUpdateReqCluster.md)
 - [ConfItem](docs/ConfItem.md)
 - [ConfItemResp](docs/ConfItemResp.md)
 - [ConfItemSetReq](docs/ConfItemSetReq.md)
 - [ConfItemSetReqConfItem](docs/ConfItemSetReqConfItem.md)
 - [ConfItemsResp](docs/ConfItemsResp.md)
 - [ConfItemsSetReq](docs/ConfItemsSetReq.md)
 - [CryptoKey](docs/CryptoKey.md)
 - [CryptoKeyCreateReq](docs/CryptoKeyCreateReq.md)
 - [CryptoKeyCreateReqKey](docs/CryptoKeyCreateReqKey.md)
 - [CryptoKeyNestview](docs/CryptoKeyNestview.md)
 - [CryptoKeyResp](docs/CryptoKeyResp.md)
 - [CryptoKeyUpdateReq](docs/CryptoKeyUpdateReq.md)
 - [CryptoKeyUpdateReqKey](docs/CryptoKeyUpdateReqKey.md)
 - [CryptoKeysResp](docs/CryptoKeysResp.md)
 - [Disk](docs/Disk.md)
 - [DiskNestview](docs/DiskNestview.md)
 - [DiskPrediction](docs/DiskPrediction.md)
 - [DiskResp](docs/DiskResp.md)
 - [DiskSamplesResp](docs/DiskSamplesResp.md)
 - [DiskStat](docs/DiskStat.md)
 - [DiskUpdateReq](docs/DiskUpdateReq.md)
 - [DiskUpdateReqDisk](docs/DiskUpdateReqDisk.md)
 - [DisksResp](docs/DisksResp.md)
 - [DpBackupBlockSnapshot](docs/DpBackupBlockSnapshot.md)
 - [DpBackupBlockSnapshotsResp](docs/DpBackupBlockSnapshotsResp.md)
 - [DpBackupBlockVolume](docs/DpBackupBlockVolume.md)
 - [DpBackupBlockVolumesResp](docs/DpBackupBlockVolumesResp.md)
 - [DpBackupCluster](docs/DpBackupCluster.md)
 - [DpBackupClustersResp](docs/DpBackupClustersResp.md)
 - [DpBlockReplicationPoliciesResp](docs/DpBlockReplicationPoliciesResp.md)
 - [DpBlockReplicationPolicy](docs/DpBlockReplicationPolicy.md)
 - [DpBlockReplicationPolicyCreateReq](docs/DpBlockReplicationPolicyCreateReq.md)
 - [DpBlockReplicationPolicyCreateReqPolicy](docs/DpBlockReplicationPolicyCreateReqPolicy.md)
 - [DpBlockReplicationPolicyNestview](docs/DpBlockReplicationPolicyNestview.md)
 - [DpBlockReplicationPolicyResp](docs/DpBlockReplicationPolicyResp.md)
 - [DpBlockReplicationPolicyUpdateReq](docs/DpBlockReplicationPolicyUpdateReq.md)
 - [DpBlockReplicationPolicyUpdateReqPolicy](docs/DpBlockReplicationPolicyUpdateReqPolicy.md)
 - [DpBlockSnapshotJob](docs/DpBlockSnapshotJob.md)
 - [DpBlockSnapshotJobsResp](docs/DpBlockSnapshotJobsResp.md)
 - [DpBlockSnapshotPlan](docs/DpBlockSnapshotPlan.md)
 - [DpBlockSnapshotPlanCreateReq](docs/DpBlockSnapshotPlanCreateReq.md)
 - [DpBlockSnapshotPlanData](docs/DpBlockSnapshotPlanData.md)
 - [DpBlockSnapshotPlanNestview](docs/DpBlockSnapshotPlanNestview.md)
 - [DpBlockSnapshotPlanResp](docs/DpBlockSnapshotPlanResp.md)
 - [DpBlockSnapshotPlanUpdateReq](docs/DpBlockSnapshotPlanUpdateReq.md)
 - [DpBlockSnapshotPlanUpdateReqPlan](docs/DpBlockSnapshotPlanUpdateReqPlan.md)
 - [DpBlockSnapshotPlansResp](docs/DpBlockSnapshotPlansResp.md)
 - [DpBlockSnapshotPoliciesResp](docs/DpBlockSnapshotPoliciesResp.md)
 - [DpBlockSnapshotPolicy](docs/DpBlockSnapshotPolicy.md)
 - [DpBlockSnapshotPolicyCreateReq](docs/DpBlockSnapshotPolicyCreateReq.md)
 - [DpBlockSnapshotPolicyCreateReqPolicy](docs/DpBlockSnapshotPolicyCreateReqPolicy.md)
 - [DpBlockSnapshotPolicyNestview](docs/DpBlockSnapshotPolicyNestview.md)
 - [DpBlockSnapshotPolicyResp](docs/DpBlockSnapshotPolicyResp.md)
 - [DpBlockSnapshotPolicyUpdateReq](docs/DpBlockSnapshotPolicyUpdateReq.md)
 - [DpBlockSnapshotPolicyUpdateReqPolicy](docs/DpBlockSnapshotPolicyUpdateReqPolicy.md)
 - [DpBlockSnapshotRecoveryJob](docs/DpBlockSnapshotRecoveryJob.md)
 - [DpBlockSnapshotRecoveryJobCreateReq](docs/DpBlockSnapshotRecoveryJobCreateReq.md)
 - [DpBlockSnapshotRecoveryJobCreateReqJob](docs/DpBlockSnapshotRecoveryJobCreateReqJob.md)
 - [DpBlockSnapshotRecoveryJobCreateReqJobBackupCluster](docs/DpBlockSnapshotRecoveryJobCreateReqJobBackupCluster.md)
 - [DpBlockSnapshotRecoveryJobCreateReqJobBackupSnapshot](docs/DpBlockSnapshotRecoveryJobCreateReqJobBackupSnapshot.md)
 - [DpBlockSnapshotRecoveryJobCreateReqJobBackupVolume](docs/DpBlockSnapshotRecoveryJobCreateReqJobBackupVolume.md)
 - [DpBlockSnapshotRecoveryJobCreateReqJobVolume](docs/DpBlockSnapshotRecoveryJobCreateReqJobVolume.md)
 - [DpBlockSnapshotRecoveryJobResp](docs/DpBlockSnapshotRecoveryJobResp.md)
 - [DpBlockSnapshotRecoveryJobsResp](docs/DpBlockSnapshotRecoveryJobsResp.md)
 - [DpGateway](docs/DpGateway.md)
 - [DpGatewayCreateReq](docs/DpGatewayCreateReq.md)
 - [DpGatewayCreateReqGateway](docs/DpGatewayCreateReqGateway.md)
 - [DpGatewayNestview](docs/DpGatewayNestview.md)
 - [DpGatewayResp](docs/DpGatewayResp.md)
 - [DpGatewayUpdateReq](docs/DpGatewayUpdateReq.md)
 - [DpGatewayUpdateReqGateway](docs/DpGatewayUpdateReqGateway.md)
 - [DpGatewaysResp](docs/DpGatewaysResp.md)
 - [DpSite](docs/DpSite.md)
 - [DpSiteConfig](docs/DpSiteConfig.md)
 - [DpSiteCreateReq](docs/DpSiteCreateReq.md)
 - [DpSiteCreateReqSite](docs/DpSiteCreateReqSite.md)
 - [DpSiteNestview](docs/DpSiteNestview.md)
 - [DpSiteResp](docs/DpSiteResp.md)
 - [DpSiteUpdateReq](docs/DpSiteUpdateReq.md)
 - [DpSiteUpdateReqSite](docs/DpSiteUpdateReqSite.md)
 - [DpSitesResp](docs/DpSitesResp.md)
 - [Email](docs/Email.md)
 - [EmailConfig](docs/EmailConfig.md)
 - [EmailConfigResp](docs/EmailConfigResp.md)
 - [EmailConfigUpdateReq](docs/EmailConfigUpdateReq.md)
 - [EmailConfigUpdateReqEmailConfig](docs/EmailConfigUpdateReqEmailConfig.md)
 - [EmailGroup](docs/EmailGroup.md)
 - [EmailGroupResp](docs/EmailGroupResp.md)
 - [EmailGroupUpdateReq](docs/EmailGroupUpdateReq.md)
 - [EmailGroupUpdateReqEmailGroup](docs/EmailGroupUpdateReqEmailGroup.md)
 - [EmailGroupsResp](docs/EmailGroupsResp.md)
 - [EmailResp](docs/EmailResp.md)
 - [EmailSendReq](docs/EmailSendReq.md)
 - [EmailSendReqEmail](docs/EmailSendReqEmail.md)
 - [EventLog](docs/EventLog.md)
 - [EventLogsResp](docs/EventLogsResp.md)
 - [FSADUser](docs/FSADUser.md)
 - [FSADUserResp](docs/FSADUserResp.md)
 - [FSADUsersResp](docs/FSADUsersResp.md)
 - [FSAccessGroup](docs/FSAccessGroup.md)
 - [FSAccessGroupAddMembersReq](docs/FSAccessGroupAddMembersReq.md)
 - [FSAccessGroupAddMembersReqAccessGroup](docs/FSAccessGroupAddMembersReqAccessGroup.md)
 - [FSAccessGroupCreateReq](docs/FSAccessGroupCreateReq.md)
 - [FSAccessGroupCreateReqAccessGroup](docs/FSAccessGroupCreateReqAccessGroup.md)
 - [FSAccessGroupNestview](docs/FSAccessGroupNestview.md)
 - [FSAccessGroupRemoveMembersReq](docs/FSAccessGroupRemoveMembersReq.md)
 - [FSAccessGroupRemoveMembersReqAccessGroup](docs/FSAccessGroupRemoveMembersReqAccessGroup.md)
 - [FSAccessGroupResp](docs/FSAccessGroupResp.md)
 - [FSAccessGroupUpdateReq](docs/FSAccessGroupUpdateReq.md)
 - [FSAccessGroupUpdateReqAccessGroup](docs/FSAccessGroupUpdateReqAccessGroup.md)
 - [FSAccessGroupsResp](docs/FSAccessGroupsResp.md)
 - [FSActiveDirectoriesResp](docs/FSActiveDirectoriesResp.md)
 - [FSActiveDirectory](docs/FSActiveDirectory.md)
 - [FSActiveDirectoryCreateReq](docs/FSActiveDirectoryCreateReq.md)
 - [FSActiveDirectoryCreateReqInfo](docs/FSActiveDirectoryCreateReqInfo.md)
 - [FSActiveDirectoryNestview](docs/FSActiveDirectoryNestview.md)
 - [FSActiveDirectoryResp](docs/FSActiveDirectoryResp.md)
 - [FSActiveDirectoryUpdateReq](docs/FSActiveDirectoryUpdateReq.md)
 - [FSActiveDirectoryUpdateReqInfo](docs/FSActiveDirectoryUpdateReqInfo.md)
 - [FSArbitrationPool](docs/FSArbitrationPool.md)
 - [FSArbitrationPoolCreateReq](docs/FSArbitrationPoolCreateReq.md)
 - [FSArbitrationPoolCreateReqInfo](docs/FSArbitrationPoolCreateReqInfo.md)
 - [FSArbitrationPoolResp](docs/FSArbitrationPoolResp.md)
 - [FSArbitrationPoolUpdateReq](docs/FSArbitrationPoolUpdateReq.md)
 - [FSArbitrationPoolUpdateReqInfo](docs/FSArbitrationPoolUpdateReqInfo.md)
 - [FSArbitrationPoolsResp](docs/FSArbitrationPoolsResp.md)
 - [FSClient](docs/FSClient.md)
 - [FSClientCreateReq](docs/FSClientCreateReq.md)
 - [FSClientCreateReqClient](docs/FSClientCreateReqClient.md)
 - [FSClientGroup](docs/FSClientGroup.md)
 - [FSClientGroupAddClientsReq](docs/FSClientGroupAddClientsReq.md)
 - [FSClientGroupAddClientsReqClientGroup](docs/FSClientGroupAddClientsReqClientGroup.md)
 - [FSClientGroupCreateReq](docs/FSClientGroupCreateReq.md)
 - [FSClientGroupCreateReqClientGroup](docs/FSClientGroupCreateReqClientGroup.md)
 - [FSClientGroupNestview](docs/FSClientGroupNestview.md)
 - [FSClientGroupRemoveClientsReq](docs/FSClientGroupRemoveClientsReq.md)
 - [FSClientGroupRemoveClientsReqClientGroup](docs/FSClientGroupRemoveClientsReqClientGroup.md)
 - [FSClientGroupResp](docs/FSClientGroupResp.md)
 - [FSClientGroupUpdateReq](docs/FSClientGroupUpdateReq.md)
 - [FSClientGroupUpdateReqClientGroup](docs/FSClientGroupUpdateReqClientGroup.md)
 - [FSClientGroupsResp](docs/FSClientGroupsResp.md)
 - [FSClientNestview](docs/FSClientNestview.md)
 - [FSClientResp](docs/FSClientResp.md)
 - [FSClientUpdateReq](docs/FSClientUpdateReq.md)
 - [FSClientUpdateReqClient](docs/FSClientUpdateReqClient.md)
 - [FSClientsResp](docs/FSClientsResp.md)
 - [FSFolder](docs/FSFolder.md)
 - [FSFolderCreateReq](docs/FSFolderCreateReq.md)
 - [FSFolderCreateReqFolder](docs/FSFolderCreateReqFolder.md)
 - [FSFolderNestview](docs/FSFolderNestview.md)
 - [FSFolderResp](docs/FSFolderResp.md)
 - [FSFolderSamplesResp](docs/FSFolderSamplesResp.md)
 - [FSFolderStat](docs/FSFolderStat.md)
 - [FSFolderUpdateReq](docs/FSFolderUpdateReq.md)
 - [FSFolderUpdateReqFolder](docs/FSFolderUpdateReqFolder.md)
 - [FSFoldersResp](docs/FSFoldersResp.md)
 - [FSGateway](docs/FSGateway.md)
 - [FSGatewayGroup](docs/FSGatewayGroup.md)
 - [FSGatewayGroupAddGatewaysReq](docs/FSGatewayGroupAddGatewaysReq.md)
 - [FSGatewayGroupAddGatewaysReqGatewayGroup](docs/FSGatewayGroupAddGatewaysReqGatewayGroup.md)
 - [FSGatewayGroupCreateReq](docs/FSGatewayGroupCreateReq.md)
 - [FSGatewayGroupCreateReqGatewayGroup](docs/FSGatewayGroupCreateReqGatewayGroup.md)
 - [FSGatewayGroupNestview](docs/FSGatewayGroupNestview.md)
 - [FSGatewayGroupRemoveGatewaysReq](docs/FSGatewayGroupRemoveGatewaysReq.md)
 - [FSGatewayGroupRemoveGatewaysReqGatewayGroup](docs/FSGatewayGroupRemoveGatewaysReqGatewayGroup.md)
 - [FSGatewayGroupResp](docs/FSGatewayGroupResp.md)
 - [FSGatewayGroupUpdateReq](docs/FSGatewayGroupUpdateReq.md)
 - [FSGatewayGroupUpdateReqGatewayGroup](docs/FSGatewayGroupUpdateReqGatewayGroup.md)
 - [FSGatewayGroupsResp](docs/FSGatewayGroupsResp.md)
 - [FSGatewayNestview](docs/FSGatewayNestview.md)
 - [FSGatewayReq](docs/FSGatewayReq.md)
 - [FSGatewayResp](docs/FSGatewayResp.md)
 - [FSGatewaysResp](docs/FSGatewaysResp.md)
 - [FSLdap](docs/FSLdap.md)
 - [FSLdapCreateReq](docs/FSLdapCreateReq.md)
 - [FSLdapCreateReqInfo](docs/FSLdapCreateReqInfo.md)
 - [FSLdapNestview](docs/FSLdapNestview.md)
 - [FSLdapResp](docs/FSLdapResp.md)
 - [FSLdapUpdateReq](docs/FSLdapUpdateReq.md)
 - [FSLdapUpdateReqInfo](docs/FSLdapUpdateReqInfo.md)
 - [FSLdapUser](docs/FSLdapUser.md)
 - [FSLdapUserResp](docs/FSLdapUserResp.md)
 - [FSLdapUsersResp](docs/FSLdapUsersResp.md)
 - [FSLdapsResp](docs/FSLdapsResp.md)
 - [FSShare](docs/FSShare.md)
 - [FSShareACL](docs/FSShareACL.md)
 - [FSShareACLReq](docs/FSShareACLReq.md)
 - [FSShareACLsResp](docs/FSShareACLsResp.md)
 - [FSShareAddACLsReq](docs/FSShareAddACLsReq.md)
 - [FSShareAddACLsReqShare](docs/FSShareAddACLsReqShare.md)
 - [FSShareCreateReq](docs/FSShareCreateReq.md)
 - [FSShareCreateReqShare](docs/FSShareCreateReqShare.md)
 - [FSShareMapping](docs/FSShareMapping.md)
 - [FSShareMappingsResp](docs/FSShareMappingsResp.md)
 - [FSShareNestview](docs/FSShareNestview.md)
 - [FSShareRemoveACLsReq](docs/FSShareRemoveACLsReq.md)
 - [FSShareRemoveACLsReqShare](docs/FSShareRemoveACLsReqShare.md)
 - [FSShareResp](docs/FSShareResp.md)
 - [FSShareUpdateReq](docs/FSShareUpdateReq.md)
 - [FSShareUpdateReqShare](docs/FSShareUpdateReqShare.md)
 - [FSSharesResp](docs/FSSharesResp.md)
 - [FSSnapshot](docs/FSSnapshot.md)
 - [FSSnapshotCreateReq](docs/FSSnapshotCreateReq.md)
 - [FSSnapshotCreateReqSnapshot](docs/FSSnapshotCreateReqSnapshot.md)
 - [FSSnapshotNestview](docs/FSSnapshotNestview.md)
 - [FSSnapshotResp](docs/FSSnapshotResp.md)
 - [FSSnapshotUpdateReq](docs/FSSnapshotUpdateReq.md)
 - [FSSnapshotUpdateReqSnapshot](docs/FSSnapshotUpdateReqSnapshot.md)
 - [FSSnapshotsResp](docs/FSSnapshotsResp.md)
 - [FSUser](docs/FSUser.md)
 - [FSUserCreateReq](docs/FSUserCreateReq.md)
 - [FSUserCreateReqUser](docs/FSUserCreateReqUser.md)
 - [FSUserNestview](docs/FSUserNestview.md)
 - [FSUserResp](docs/FSUserResp.md)
 - [FSUserUpdateReq](docs/FSUserUpdateReq.md)
 - [FSUserUpdateReqUser](docs/FSUserUpdateReqUser.md)
 - [FSUsersResp](docs/FSUsersResp.md)
 - [Host](docs/Host.md)
 - [HostCreateReq](docs/HostCreateReq.md)
 - [HostCreateReqHost](docs/HostCreateReqHost.md)
 - [HostFcPort](docs/HostFcPort.md)
 - [HostInfo](docs/HostInfo.md)
 - [HostInfoResp](docs/HostInfoResp.md)
 - [HostNestview](docs/HostNestview.md)
 - [HostResp](docs/HostResp.md)
 - [HostSamplesResp](docs/HostSamplesResp.md)
 - [HostStat](docs/HostStat.md)
 - [HostUpdateReq](docs/HostUpdateReq.md)
 - [HostUpdateReqHost](docs/HostUpdateReqHost.md)
 - [HostValidator](docs/HostValidator.md)
 - [HostValidatorCreateReq](docs/HostValidatorCreateReq.md)
 - [HostValidatorCreateReqValidator](docs/HostValidatorCreateReqValidator.md)
 - [HostValidatorResp](docs/HostValidatorResp.md)
 - [HostsResp](docs/HostsResp.md)
 - [IdentityPlatform](docs/IdentityPlatform.md)
 - [IdentityPlatformCreateReq](docs/IdentityPlatformCreateReq.md)
 - [IdentityPlatformCreateReqPlatform](docs/IdentityPlatformCreateReqPlatform.md)
 - [IdentityPlatformNestview](docs/IdentityPlatformNestview.md)
 - [IdentityPlatformResp](docs/IdentityPlatformResp.md)
 - [IdentityPlatformUpdateReq](docs/IdentityPlatformUpdateReq.md)
 - [IdentityPlatformUpdateReqPlatform](docs/IdentityPlatformUpdateReqPlatform.md)
 - [IdentityPlatformsResp](docs/IdentityPlatformsResp.md)
 - [License](docs/License.md)
 - [LicenseResp](docs/LicenseResp.md)
 - [LicensesResp](docs/LicensesResp.md)
 - [LifecycleRule](docs/LifecycleRule.md)
 - [LifecycleTransitionBase](docs/LifecycleTransitionBase.md)
 - [Lun](docs/Lun.md)
 - [LunNestview](docs/LunNestview.md)
 - [LunResp](docs/LunResp.md)
 - [LunsResp](docs/LunsResp.md)
 - [MappingGroup](docs/MappingGroup.md)
 - [MappingGroupAddVolumesReq](docs/MappingGroupAddVolumesReq.md)
 - [MappingGroupCreateReq](docs/MappingGroupCreateReq.md)
 - [MappingGroupRemoveVolumesReq](docs/MappingGroupRemoveVolumesReq.md)
 - [MappingGroupReq](docs/MappingGroupReq.md)
 - [MappingGroupResp](docs/MappingGroupResp.md)
 - [MappingGroupUpdateClientGroupReq](docs/MappingGroupUpdateClientGroupReq.md)
 - [MappingGroupUpdateReq](docs/MappingGroupUpdateReq.md)
 - [MappingGroupUpdateReqMappingGroup](docs/MappingGroupUpdateReqMappingGroup.md)
 - [MappingGroupsResp](docs/MappingGroupsResp.md)
 - [MultiObjectStorageBucketsSamplesResp](docs/MultiObjectStorageBucketsSamplesResp.md)
 - [MultiS3LoadBalancersSamplesResp](docs/MultiS3LoadBalancersSamplesResp.md)
 - [MultiVolumesSamplesResp](docs/MultiVolumesSamplesResp.md)
 - [NFSGateway](docs/NFSGateway.md)
 - [NFSGatewayActionReq](docs/NFSGatewayActionReq.md)
 - [NFSGatewayActionReqNFSGateway](docs/NFSGatewayActionReqNFSGateway.md)
 - [NFSGatewayBucketMap](docs/NFSGatewayBucketMap.md)
 - [NFSGatewayBucketMapResp](docs/NFSGatewayBucketMapResp.md)
 - [NFSGatewayBucketMapUpdateReq](docs/NFSGatewayBucketMapUpdateReq.md)
 - [NFSGatewayBucketMapUpdateReqNFSGatewayBucketMap](docs/NFSGatewayBucketMapUpdateReqNFSGatewayBucketMap.md)
 - [NFSGatewayBucketMapsResp](docs/NFSGatewayBucketMapsResp.md)
 - [NFSGatewayCreateReq](docs/NFSGatewayCreateReq.md)
 - [NFSGatewayCreateReqNFSGateway](docs/NFSGatewayCreateReqNFSGateway.md)
 - [NFSGatewayNestview](docs/NFSGatewayNestview.md)
 - [NFSGatewayResp](docs/NFSGatewayResp.md)
 - [NFSGatewaySamplesResp](docs/NFSGatewaySamplesResp.md)
 - [NFSGatewayStat](docs/NFSGatewayStat.md)
 - [NFSGatewayUpdateReq](docs/NFSGatewayUpdateReq.md)
 - [NFSGatewayUpdateReqNFSGateway](docs/NFSGatewayUpdateReqNFSGateway.md)
 - [NFSGatewaysResp](docs/NFSGatewaysResp.md)
 - [NetworkAddress](docs/NetworkAddress.md)
 - [NetworkAddressResp](docs/NetworkAddressResp.md)
 - [NetworkAddressesResp](docs/NetworkAddressesResp.md)
 - [NetworkInterface](docs/NetworkInterface.md)
 - [NetworkInterfaceNestview](docs/NetworkInterfaceNestview.md)
 - [NetworkInterfaceResp](docs/NetworkInterfaceResp.md)
 - [NetworkInterfaceSamplesResp](docs/NetworkInterfaceSamplesResp.md)
 - [NetworkInterfaceStat](docs/NetworkInterfaceStat.md)
 - [NetworkInterfacesResp](docs/NetworkInterfacesResp.md)
 - [ObjectStorage](docs/ObjectStorage.md)
 - [ObjectStorageArchivePool](docs/ObjectStorageArchivePool.md)
 - [ObjectStorageArchivePoolCreateReq](docs/ObjectStorageArchivePoolCreateReq.md)
 - [ObjectStorageArchivePoolCreateReqArchivePool](docs/ObjectStorageArchivePoolCreateReqArchivePool.md)
 - [ObjectStorageArchivePoolResp](docs/ObjectStorageArchivePoolResp.md)
 - [ObjectStorageArchivePoolUpdateReq](docs/ObjectStorageArchivePoolUpdateReq.md)
 - [ObjectStorageArchivePoolUpdateReqArchivePool](docs/ObjectStorageArchivePoolUpdateReqArchivePool.md)
 - [ObjectStorageArchivePoolsResp](docs/ObjectStorageArchivePoolsResp.md)
 - [ObjectStorageBucket](docs/ObjectStorageBucket.md)
 - [ObjectStorageBucketCreateReq](docs/ObjectStorageBucketCreateReq.md)
 - [ObjectStorageBucketCreateReqBucket](docs/ObjectStorageBucketCreateReqBucket.md)
 - [ObjectStorageBucketNFSClient](docs/ObjectStorageBucketNFSClient.md)
 - [ObjectStorageBucketNFSClientResp](docs/ObjectStorageBucketNFSClientResp.md)
 - [ObjectStorageBucketNFSClientUpdateReq](docs/ObjectStorageBucketNFSClientUpdateReq.md)
 - [ObjectStorageBucketNFSClientUpdateReqClient](docs/ObjectStorageBucketNFSClientUpdateReqClient.md)
 - [ObjectStorageBucketNFSClientsCreateReq](docs/ObjectStorageBucketNFSClientsCreateReq.md)
 - [ObjectStorageBucketNFSClientsCreateReqClientsElt](docs/ObjectStorageBucketNFSClientsCreateReqClientsElt.md)
 - [ObjectStorageBucketNFSClientsDeleteReq](docs/ObjectStorageBucketNFSClientsDeleteReq.md)
 - [ObjectStorageBucketNFSClientsResp](docs/ObjectStorageBucketNFSClientsResp.md)
 - [ObjectStorageBucketNestview](docs/ObjectStorageBucketNestview.md)
 - [ObjectStorageBucketNestviewLifecycle](docs/ObjectStorageBucketNestviewLifecycle.md)
 - [ObjectStorageBucketResp](docs/ObjectStorageBucketResp.md)
 - [ObjectStorageBucketSamplesElem](docs/ObjectStorageBucketSamplesElem.md)
 - [ObjectStorageBucketSamplesResp](docs/ObjectStorageBucketSamplesResp.md)
 - [ObjectStorageBucketStat](docs/ObjectStorageBucketStat.md)
 - [ObjectStorageBucketUpdateReq](docs/ObjectStorageBucketUpdateReq.md)
 - [ObjectStorageBucketUpdateReqBucket](docs/ObjectStorageBucketUpdateReqBucket.md)
 - [ObjectStorageBucketsResp](docs/ObjectStorageBucketsResp.md)
 - [ObjectStorageGateway](docs/ObjectStorageGateway.md)
 - [ObjectStorageGatewayCreateReq](docs/ObjectStorageGatewayCreateReq.md)
 - [ObjectStorageGatewayCreateReqGateway](docs/ObjectStorageGatewayCreateReqGateway.md)
 - [ObjectStorageGatewayResp](docs/ObjectStorageGatewayResp.md)
 - [ObjectStorageGatewaySamplesResp](docs/ObjectStorageGatewaySamplesResp.md)
 - [ObjectStorageGatewayStat](docs/ObjectStorageGatewayStat.md)
 - [ObjectStorageGatewayUpdateReq](docs/ObjectStorageGatewayUpdateReq.md)
 - [ObjectStorageGatewayUpdateReqGateway](docs/ObjectStorageGatewayUpdateReqGateway.md)
 - [ObjectStorageGatewaysResp](docs/ObjectStorageGatewaysResp.md)
 - [ObjectStorageInitReq](docs/ObjectStorageInitReq.md)
 - [ObjectStorageInitReqInfo](docs/ObjectStorageInitReqInfo.md)
 - [ObjectStorageKey](docs/ObjectStorageKey.md)
 - [ObjectStorageKeyCreateReq](docs/ObjectStorageKeyCreateReq.md)
 - [ObjectStorageKeyCreateReqKey](docs/ObjectStorageKeyCreateReqKey.md)
 - [ObjectStorageKeyNestview](docs/ObjectStorageKeyNestview.md)
 - [ObjectStorageKeyResp](docs/ObjectStorageKeyResp.md)
 - [ObjectStorageKeyUpdateReq](docs/ObjectStorageKeyUpdateReq.md)
 - [ObjectStorageKeyUpdateReqKey](docs/ObjectStorageKeyUpdateReqKey.md)
 - [ObjectStorageKeysResp](docs/ObjectStorageKeysResp.md)
 - [ObjectStorageLifecycle](docs/ObjectStorageLifecycle.md)
 - [ObjectStorageLifecycleResp](docs/ObjectStorageLifecycleResp.md)
 - [ObjectStorageLifecycleSetReq](docs/ObjectStorageLifecycleSetReq.md)
 - [ObjectStorageLifecyclesResp](docs/ObjectStorageLifecyclesResp.md)
 - [ObjectStoragePoliciesResp](docs/ObjectStoragePoliciesResp.md)
 - [ObjectStoragePolicy](docs/ObjectStoragePolicy.md)
 - [ObjectStoragePolicyCreateReq](docs/ObjectStoragePolicyCreateReq.md)
 - [ObjectStoragePolicyCreateReqPolicy](docs/ObjectStoragePolicyCreateReqPolicy.md)
 - [ObjectStoragePolicyNestview](docs/ObjectStoragePolicyNestview.md)
 - [ObjectStoragePolicyResp](docs/ObjectStoragePolicyResp.md)
 - [ObjectStoragePolicyUpdateReq](docs/ObjectStoragePolicyUpdateReq.md)
 - [ObjectStoragePolicyUpdateReqPolicy](docs/ObjectStoragePolicyUpdateReqPolicy.md)
 - [ObjectStorageReplicationPoliciesResp](docs/ObjectStorageReplicationPoliciesResp.md)
 - [ObjectStorageReplicationPolicy](docs/ObjectStorageReplicationPolicy.md)
 - [ObjectStorageReplicationPolicyCreateReq](docs/ObjectStorageReplicationPolicyCreateReq.md)
 - [ObjectStorageReplicationPolicyCreateReqPolicy](docs/ObjectStorageReplicationPolicyCreateReqPolicy.md)
 - [ObjectStorageReplicationPolicyNestview](docs/ObjectStorageReplicationPolicyNestview.md)
 - [ObjectStorageReplicationPolicyResp](docs/ObjectStorageReplicationPolicyResp.md)
 - [ObjectStorageReplicationRuleItem](docs/ObjectStorageReplicationRuleItem.md)
 - [ObjectStorageResp](docs/ObjectStorageResp.md)
 - [ObjectStorageSetReq](docs/ObjectStorageSetReq.md)
 - [ObjectStorageSetReqInfo](docs/ObjectStorageSetReqInfo.md)
 - [ObjectStorageUser](docs/ObjectStorageUser.md)
 - [ObjectStorageUserCreateReq](docs/ObjectStorageUserCreateReq.md)
 - [ObjectStorageUserCreateReqInfo](docs/ObjectStorageUserCreateReqInfo.md)
 - [ObjectStorageUserNestview](docs/ObjectStorageUserNestview.md)
 - [ObjectStorageUserResp](docs/ObjectStorageUserResp.md)
 - [ObjectStorageUserSamplesResp](docs/ObjectStorageUserSamplesResp.md)
 - [ObjectStorageUserStat](docs/ObjectStorageUserStat.md)
 - [ObjectStorageUserUpdateReq](docs/ObjectStorageUserUpdateReq.md)
 - [ObjectStorageUserUpdateReqInfo](docs/ObjectStorageUserUpdateReqInfo.md)
 - [ObjectStorageUsersResp](docs/ObjectStorageUsersResp.md)
 - [ObjectStorageZone](docs/ObjectStorageZone.md)
 - [ObjectStorageZoneCreateReq](docs/ObjectStorageZoneCreateReq.md)
 - [ObjectStorageZoneCreateReqZone](docs/ObjectStorageZoneCreateReqZone.md)
 - [ObjectStorageZoneInfo](docs/ObjectStorageZoneInfo.md)
 - [ObjectStorageZoneNestview](docs/ObjectStorageZoneNestview.md)
 - [ObjectStorageZoneResp](docs/ObjectStorageZoneResp.md)
 - [ObjectStorageZoneUpdateReq](docs/ObjectStorageZoneUpdateReq.md)
 - [ObjectStorageZoneUpdateReqZone](docs/ObjectStorageZoneUpdateReqZone.md)
 - [ObjectStorageZonesResp](docs/ObjectStorageZonesResp.md)
 - [Osd](docs/Osd.md)
 - [OsdCreateReq](docs/OsdCreateReq.md)
 - [OsdCreateReqOsd](docs/OsdCreateReqOsd.md)
 - [OsdPredictionsResp](docs/OsdPredictionsResp.md)
 - [OsdQos](docs/OsdQos.md)
 - [OsdResp](docs/OsdResp.md)
 - [OsdSamplesResp](docs/OsdSamplesResp.md)
 - [OsdUpdateReq](docs/OsdUpdateReq.md)
 - [OsdUpdateReqOsd](docs/OsdUpdateReqOsd.md)
 - [OsdsAddReq](docs/OsdsAddReq.md)
 - [OsdsRemoveReq](docs/OsdsRemoveReq.md)
 - [OsdsResp](docs/OsdsResp.md)
 - [Paging](docs/Paging.md)
 - [Partition](docs/Partition.md)
 - [PartitionStat](docs/PartitionStat.md)
 - [PlacementGroup](docs/PlacementGroup.md)
 - [PlacementGroupScrub](docs/PlacementGroupScrub.md)
 - [PlacementNode](docs/PlacementNode.md)
 - [PlacementNodeCreateReq](docs/PlacementNodeCreateReq.md)
 - [PlacementNodeCreateReqPlacementNode](docs/PlacementNodeCreateReqPlacementNode.md)
 - [PlacementNodeNestview](docs/PlacementNodeNestview.md)
 - [PlacementNodeNestviewParent](docs/PlacementNodeNestviewParent.md)
 - [PlacementNodeResp](docs/PlacementNodeResp.md)
 - [PlacementNodeTopologyResp](docs/PlacementNodeTopologyResp.md)
 - [PlacementNodeUpdateReq](docs/PlacementNodeUpdateReq.md)
 - [PlacementNodeUpdateReqPlacementNode](docs/PlacementNodeUpdateReqPlacementNode.md)
 - [Pool](docs/Pool.md)
 - [PoolCreateReq](docs/PoolCreateReq.md)
 - [PoolCreateReqPool](docs/PoolCreateReqPool.md)
 - [PoolNestview](docs/PoolNestview.md)
 - [PoolPlacementNode](docs/PoolPlacementNode.md)
 - [PoolPrediction](docs/PoolPrediction.md)
 - [PoolPredictionsResp](docs/PoolPredictionsResp.md)
 - [PoolResp](docs/PoolResp.md)
 - [PoolRuleReq](docs/PoolRuleReq.md)
 - [PoolSamplesResp](docs/PoolSamplesResp.md)
 - [PoolStat](docs/PoolStat.md)
 - [PoolTopologyResp](docs/PoolTopologyResp.md)
 - [PoolUpdateReq](docs/PoolUpdateReq.md)
 - [PoolUpdateReqPool](docs/PoolUpdateReqPool.md)
 - [PoolsResp](docs/PoolsResp.md)
 - [PredictionPoint](docs/PredictionPoint.md)
 - [ProtectionDomain](docs/ProtectionDomain.md)
 - [ProtectionDomainNestview](docs/ProtectionDomainNestview.md)
 - [ProtectionDomainRecordResp](docs/ProtectionDomainRecordResp.md)
 - [ProtectionDomainRecordsResp](docs/ProtectionDomainRecordsResp.md)
 - [RawMessage](docs/RawMessage.md)
 - [RawObjectStorageBucketResp](docs/RawObjectStorageBucketResp.md)
 - [RemoteCluster](docs/RemoteCluster.md)
 - [RemoteClusterCreateReq](docs/RemoteClusterCreateReq.md)
 - [RemoteClusterCreateReqRemoteCluster](docs/RemoteClusterCreateReqRemoteCluster.md)
 - [RemoteClusterNestview](docs/RemoteClusterNestview.md)
 - [RemoteClusterResp](docs/RemoteClusterResp.md)
 - [RemoteClusterUpdateReq](docs/RemoteClusterUpdateReq.md)
 - [RemoteClusterUpdateReqRemoteCluster](docs/RemoteClusterUpdateReqRemoteCluster.md)
 - [RemoteClustersResp](docs/RemoteClustersResp.md)
 - [RoleMapping](docs/RoleMapping.md)
 - [RoleMappingCreateReq](docs/RoleMappingCreateReq.md)
 - [RoleMappingCreateReqMapping](docs/RoleMappingCreateReqMapping.md)
 - [RoleMappingResp](docs/RoleMappingResp.md)
 - [RoleMappingUpdateReq](docs/RoleMappingUpdateReq.md)
 - [RoleMappingUpdateReqMapping](docs/RoleMappingUpdateReqMapping.md)
 - [RoleMappingsResp](docs/RoleMappingsResp.md)
 - [S3LoadBalancer](docs/S3LoadBalancer.md)
 - [S3LoadBalancerGroup](docs/S3LoadBalancerGroup.md)
 - [S3LoadBalancerGroupCreateReq](docs/S3LoadBalancerGroupCreateReq.md)
 - [S3LoadBalancerGroupCreateReqGroup](docs/S3LoadBalancerGroupCreateReqGroup.md)
 - [S3LoadBalancerGroupCreateReqGroupLoadBalancersElt](docs/S3LoadBalancerGroupCreateReqGroupLoadBalancersElt.md)
 - [S3LoadBalancerGroupNestview](docs/S3LoadBalancerGroupNestview.md)
 - [S3LoadBalancerGroupResp](docs/S3LoadBalancerGroupResp.md)
 - [S3LoadBalancerGroupUpdateReq](docs/S3LoadBalancerGroupUpdateReq.md)
 - [S3LoadBalancerGroupUpdateReqGroup](docs/S3LoadBalancerGroupUpdateReqGroup.md)
 - [S3LoadBalancerGroupsResp](docs/S3LoadBalancerGroupsResp.md)
 - [S3LoadBalancerResp](docs/S3LoadBalancerResp.md)
 - [S3LoadBalancerSamplesElem](docs/S3LoadBalancerSamplesElem.md)
 - [S3LoadBalancerSamplesResp](docs/S3LoadBalancerSamplesResp.md)
 - [S3LoadBalancerStat](docs/S3LoadBalancerStat.md)
 - [S3LoadBalancersAddReq](docs/S3LoadBalancersAddReq.md)
 - [S3LoadBalancersAddReqLoadBalancersElt](docs/S3LoadBalancersAddReqLoadBalancersElt.md)
 - [S3LoadBalancersRemoveReq](docs/S3LoadBalancersRemoveReq.md)
 - [S3LoadBalancersResp](docs/S3LoadBalancersResp.md)
 - [SSLCertificate](docs/SSLCertificate.md)
 - [SSLCertificateCreateReq](docs/SSLCertificateCreateReq.md)
 - [SSLCertificateCreateReqCertificate](docs/SSLCertificateCreateReqCertificate.md)
 - [SSLCertificateNestview](docs/SSLCertificateNestview.md)
 - [SSLCertificateResp](docs/SSLCertificateResp.md)
 - [SSLCertificateUpdateReq](docs/SSLCertificateUpdateReq.md)
 - [SSLCertificateUpdateReqCertificate](docs/SSLCertificateUpdateReqCertificate.md)
 - [SSLCertificatesResp](docs/SSLCertificatesResp.md)
 - [Service](docs/Service.md)
 - [ServiceResp](docs/ServiceResp.md)
 - [ServicesResp](docs/ServicesResp.md)
 - [SmartAttr](docs/SmartAttr.md)
 - [Snapshot](docs/Snapshot.md)
 - [SnapshotBackupConfig](docs/SnapshotBackupConfig.md)
 - [SnapshotCreateReq](docs/SnapshotCreateReq.md)
 - [SnapshotCreateReqSnapshot](docs/SnapshotCreateReqSnapshot.md)
 - [SnapshotNestview](docs/SnapshotNestview.md)
 - [SnapshotReplicationConfig](docs/SnapshotReplicationConfig.md)
 - [SnapshotResp](docs/SnapshotResp.md)
 - [SnapshotUpdateReq](docs/SnapshotUpdateReq.md)
 - [SnapshotUpdateReqSnapshot](docs/SnapshotUpdateReqSnapshot.md)
 - [SnapshotsResp](docs/SnapshotsResp.md)
 - [SnmpGateway](docs/SnmpGateway.md)
 - [SnmpGatewayReq](docs/SnmpGatewayReq.md)
 - [SnmpResp](docs/SnmpResp.md)
 - [SnmpRespSnmp](docs/SnmpRespSnmp.md)
 - [SnmpSetReq](docs/SnmpSetReq.md)
 - [SnmpSetReqSnmp](docs/SnmpSetReqSnmp.md)
 - [SnmpTrapReceiverReq](docs/SnmpTrapReceiverReq.md)
 - [SourceRecord](docs/SourceRecord.md)
 - [SourcesResp](docs/SourcesResp.md)
 - [SystemLog](docs/SystemLog.md)
 - [SystemLogsResp](docs/SystemLogsResp.md)
 - [Target](docs/Target.md)
 - [TargetCreateReq](docs/TargetCreateReq.md)
 - [TargetCreateReqTarget](docs/TargetCreateReqTarget.md)
 - [TargetNestview](docs/TargetNestview.md)
 - [TargetResp](docs/TargetResp.md)
 - [TargetsResp](docs/TargetsResp.md)
 - [Task](docs/Task.md)
 - [TaskResp](docs/TaskResp.md)
 - [TasksResp](docs/TasksResp.md)
 - [Token](docs/Token.md)
 - [TokenCreateReq](docs/TokenCreateReq.md)
 - [TokenCreateReqAuth](docs/TokenCreateReqAuth.md)
 - [TokenCreateReqAuthIdentity](docs/TokenCreateReqAuthIdentity.md)
 - [TokenResp](docs/TokenResp.md)
 - [TrapReceiver](docs/TrapReceiver.md)
 - [User](docs/User.md)
 - [UserCreateReq](docs/UserCreateReq.md)
 - [UserCreateReqUser](docs/UserCreateReqUser.md)
 - [UserNestview](docs/UserNestview.md)
 - [UserResp](docs/UserResp.md)
 - [UserSettings](docs/UserSettings.md)
 - [UserSettingsUser](docs/UserSettingsUser.md)
 - [UserSettingsUserSettings](docs/UserSettingsUserSettings.md)
 - [UserUpdateReq](docs/UserUpdateReq.md)
 - [UserUpdateReqUser](docs/UserUpdateReqUser.md)
 - [UsersResp](docs/UsersResp.md)
 - [VersionResp](docs/VersionResp.md)
 - [Volume](docs/Volume.md)
 - [VolumeCreateReq](docs/VolumeCreateReq.md)
 - [VolumeCreateReqVolume](docs/VolumeCreateReqVolume.md)
 - [VolumeGroup](docs/VolumeGroup.md)
 - [VolumeGroupAddVolumeReq](docs/VolumeGroupAddVolumeReq.md)
 - [VolumeGroupCreateReq](docs/VolumeGroupCreateReq.md)
 - [VolumeGroupCreateReqVolumeGroup](docs/VolumeGroupCreateReqVolumeGroup.md)
 - [VolumeGroupNestview](docs/VolumeGroupNestview.md)
 - [VolumeGroupRemoveVolumeReq](docs/VolumeGroupRemoveVolumeReq.md)
 - [VolumeGroupResp](docs/VolumeGroupResp.md)
 - [VolumeGroupSnapshot](docs/VolumeGroupSnapshot.md)
 - [VolumeGroupSnapshotCreateReq](docs/VolumeGroupSnapshotCreateReq.md)
 - [VolumeGroupSnapshotCreateReqVolumeGroupSnapshot](docs/VolumeGroupSnapshotCreateReqVolumeGroupSnapshot.md)
 - [VolumeGroupSnapshotNestview](docs/VolumeGroupSnapshotNestview.md)
 - [VolumeGroupSnapshotResp](docs/VolumeGroupSnapshotResp.md)
 - [VolumeGroupSnapshotUpdateReq](docs/VolumeGroupSnapshotUpdateReq.md)
 - [VolumeGroupSnapshotUpdateReqVolumeGroupSnapshot](docs/VolumeGroupSnapshotUpdateReqVolumeGroupSnapshot.md)
 - [VolumeGroupSnapshotsResp](docs/VolumeGroupSnapshotsResp.md)
 - [VolumeGroupUpdateReq](docs/VolumeGroupUpdateReq.md)
 - [VolumeGroupUpdateReqVolumeGroup](docs/VolumeGroupUpdateReqVolumeGroup.md)
 - [VolumeGroupsResp](docs/VolumeGroupsResp.md)
 - [VolumeMigrateReq](docs/VolumeMigrateReq.md)
 - [VolumeMigrateReqVolume](docs/VolumeMigrateReqVolume.md)
 - [VolumeNestview](docs/VolumeNestview.md)
 - [VolumeQosSpec](docs/VolumeQosSpec.md)
 - [VolumeReplicationSetReq](docs/VolumeReplicationSetReq.md)
 - [VolumeReplicationSetReqVolume](docs/VolumeReplicationSetReqVolume.md)
 - [VolumeResp](docs/VolumeResp.md)
 - [VolumeSamplesElem](docs/VolumeSamplesElem.md)
 - [VolumeSamplesResp](docs/VolumeSamplesResp.md)
 - [VolumeSnapshotProtectionReq](docs/VolumeSnapshotProtectionReq.md)
 - [VolumeSnapshotProtectionReqVolume](docs/VolumeSnapshotProtectionReqVolume.md)
 - [VolumeStat](docs/VolumeStat.md)
 - [VolumeUpdateReq](docs/VolumeUpdateReq.md)
 - [VolumeUpdateReqVolume](docs/VolumeUpdateReqVolume.md)
 - [VolumesResp](docs/VolumesResp.md)
 - [AccessTokenCreateRecord](docs/AccessTokenCreateRecord.md)
 - [ChunkRecord](docs/ChunkRecord.md)
 - [ClientLunMappingRecord](docs/ClientLunMappingRecord.md)
 - [CloudInstanceRecord](docs/CloudInstanceRecord.md)
 - [ClusterRecord](docs/ClusterRecord.md)
 - [DiskRecord](docs/DiskRecord.md)
 - [DpBlockSnapshotPlanCreateReqPlan](docs/DpBlockSnapshotPlanCreateReqPlan.md)
 - [EmailGroupRecord](docs/EmailGroupRecord.md)
 - [FSFolderRecord](docs/FSFolderRecord.md)
 - [HostRecord](docs/HostRecord.md)
 - [LifecycleExpiration](docs/LifecycleExpiration.md)
 - [LifecycleTransition](docs/LifecycleTransition.md)
 - [NFSGatewayRecord](docs/NFSGatewayRecord.md)
 - [NetworkInterfaceRecord](docs/NetworkInterfaceRecord.md)
 - [ObjectStorageBucketRecord](docs/ObjectStorageBucketRecord.md)
 - [ObjectStorageGatewayRecord](docs/ObjectStorageGatewayRecord.md)
 - [ObjectStorageUserRecord](docs/ObjectStorageUserRecord.md)
 - [OsdRecord](docs/OsdRecord.md)
 - [OsdStat](docs/OsdStat.md)
 - [PdRecord](docs/PdRecord.md)
 - [PlacementNodeRecord](docs/PlacementNodeRecord.md)
 - [PlacementNodeTopology](docs/PlacementNodeTopology.md)
 - [PoolRecord](docs/PoolRecord.md)
 - [S3LoadBalancerRecord](docs/S3LoadBalancerRecord.md)
 - [TokenRecord](docs/TokenRecord.md)
 - [UserRecord](docs/UserRecord.md)
 - [VolumeRecord](docs/VolumeRecord.md)


## Documentation For Authorization


## tokenInCookie

- **Type**: API key
- **API key parameter name**: XMS_AUTH_TOKEN
- **Location**: HTTP header

## tokenInHeader

- **Type**: API key
- **API key parameter name**: Xms-Auth-Token
- **Location**: HTTP header

## tokenInQuery

- **Type**: API key
- **API key parameter name**: token
- **Location**: URL query string


## Author



